#nullable enable
using Canon.Core.Abstractions;
using Canon.Core.GrammarParser;
using Canon.Core.Enums;
namespace Canon.Tests.GeneratedParserTests;

public class GeneratedTransformer : ITransformer
{
    private IDictionary<TerminatorBase, string> _shiftPointers;

    public string Name { get; }

    public IDictionary<Terminator, ReduceInformation> ReduceTable { get; }

    public IDictionary<TerminatorBase, ITransformer> ShiftTable { get; }

    public GeneratedTransformer(Dictionary<TerminatorBase, string> shiftTable,
        Dictionary<Terminator, ReduceInformation> reduceTable, string name)
    {
        ReduceTable = reduceTable;
        ShiftTable = new Dictionary<TerminatorBase, ITransformer>();
        _shiftPointers = shiftTable;
        Name = name;
    }

    public GeneratedTransformer()
    {
        ReduceTable = new Dictionary<Terminator, ReduceInformation>();
        ShiftTable = new Dictionary<TerminatorBase, ITransformer>();
        _shiftPointers = new Dictionary<TerminatorBase, string>();
        Name = Guid.NewGuid().ToString();
    }

    public void ConstructShiftTable(Dictionary<string, GeneratedTransformer> transformers)
    {
        foreach (KeyValuePair<TerminatorBase,string> pair in _shiftPointers)
        {
            ShiftTable.Add(pair.Key, transformers[pair.Value]);
        }
    }

    public override bool Equals(object? obj)
    {
        if (obj is not GeneratedTransformer other)
        {
            return false;
        }

        return Name == other.Name;
    }

    public override int GetHashCode() => Name.GetHashCode();
}
public class GeneratedGrammarParser : GrammarParserBase
{
	private static readonly Dictionary<string, GeneratedTransformer> s_transformers = new()
	{
		{ "f73d22cc-ac40-46ec-8150-8772c03417b9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ProgramStruct), "93f4cc5b-f5f9-47c5-9c27-d8232ed9b41c"}, { new NonTerminator(NonTerminatorType.ProgramHead), "a5fb6eee-4eb4-47a7-9076-d37cacd73137"}, { new Terminator(KeywordType.Program), "cd87f80a-1d67-4314-adf5-0286be4b84b4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f73d22cc-ac40-46ec-8150-8772c03417b9") },
		{ "93f4cc5b-f5f9-47c5-9c27-d8232ed9b41c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.EndTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.StartNonTerminator))}, }, "93f4cc5b-f5f9-47c5-9c27-d8232ed9b41c") },
		{ "a5fb6eee-4eb4-47a7-9076-d37cacd73137", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "9f931e39-3dda-4442-a0d2-00366e13bba7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a5fb6eee-4eb4-47a7-9076-d37cacd73137") },
		{ "cd87f80a-1d67-4314-adf5-0286be4b84b4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "fd99600d-9ba3-4c30-a168-fbafa54fdd07"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cd87f80a-1d67-4314-adf5-0286be4b84b4") },
		{ "9f931e39-3dda-4442-a0d2-00366e13bba7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ProgramBody), "89ec3a30-25a0-4c91-b08f-e03ec90fe303"}, { new NonTerminator(NonTerminatorType.ConstDeclarations), "d3becd2a-f640-4519-a74e-dc46787e059f"}, { new Terminator(KeywordType.Const), "9bbeb6e3-e7ec-42e8-8d5f-76e8f0691a52"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "9f931e39-3dda-4442-a0d2-00366e13bba7") },
		{ "fd99600d-9ba3-4c30-a168-fbafa54fdd07", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "223dd952-d42c-4142-9bf3-0ffaf67cdfa0"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ProgramHead))}, }, "fd99600d-9ba3-4c30-a168-fbafa54fdd07") },
		{ "89ec3a30-25a0-4c91-b08f-e03ec90fe303", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Period), "e3d245f1-90bc-4886-95ad-abcaac21421e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "89ec3a30-25a0-4c91-b08f-e03ec90fe303") },
		{ "d3becd2a-f640-4519-a74e-dc46787e059f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclarations), "4b4367f6-547c-48dd-9c79-dedf02be09aa"}, { new Terminator(KeywordType.Var), "fc46d9de-be4c-4926-9fb2-dbb70fd7fe64"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "d3becd2a-f640-4519-a74e-dc46787e059f") },
		{ "9bbeb6e3-e7ec-42e8-8d5f-76e8f0691a52", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstDeclaration), "acc8f59f-3ccf-41cc-b390-befe49a441fc"}, { Terminator.IdentifierTerminator, "129a8062-876b-46ff-b339-8044078a546e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9bbeb6e3-e7ec-42e8-8d5f-76e8f0691a52") },
		{ "223dd952-d42c-4142-9bf3-0ffaf67cdfa0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.IdentifierList), "a187908e-87a9-4a20-8b40-58208c38efe7"}, { Terminator.IdentifierTerminator, "9ebc6625-fade-41b7-a22e-653259af07f4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "223dd952-d42c-4142-9bf3-0ffaf67cdfa0") },
		{ "e3d245f1-90bc-4886-95ad-abcaac21421e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.EndTerminator, new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProgramStruct))}, }, "e3d245f1-90bc-4886-95ad-abcaac21421e") },
		{ "4b4367f6-547c-48dd-9c79-dedf02be09aa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SubprogramDeclarations), "1ab4bd3d-2471-48fa-bc82-d5ab024b6f1d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, }, "4b4367f6-547c-48dd-9c79-dedf02be09aa") },
		{ "fc46d9de-be4c-4926-9fb2-dbb70fd7fe64", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclaration), "6cc5a977-b2f5-450f-9022-a831d1f02804"}, { new NonTerminator(NonTerminatorType.IdentifierList), "232721fd-a9bb-44be-861f-0e5dc342ccd8"}, { Terminator.IdentifierTerminator, "9dc91f71-af68-404e-b670-a90589c075ea"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fc46d9de-be4c-4926-9fb2-dbb70fd7fe64") },
		{ "acc8f59f-3ccf-41cc-b390-befe49a441fc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "73839b71-0170-4ed7-b301-cf9520bdde12"},}, new Dictionary<Terminator, ReduceInformation>{ }, "acc8f59f-3ccf-41cc-b390-befe49a441fc") },
		{ "129a8062-876b-46ff-b339-8044078a546e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Equal), "4a53b2fc-7772-49f9-94a8-8a0a37f5e02b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "129a8062-876b-46ff-b339-8044078a546e") },
		{ "a187908e-87a9-4a20-8b40-58208c38efe7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "f705e5ad-198b-45a7-a2ff-27eace11510f"}, { new Terminator(DelimiterType.Comma), "b4d5eac1-ef91-4843-8ac8-228ccd299991"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a187908e-87a9-4a20-8b40-58208c38efe7") },
		{ "9ebc6625-fade-41b7-a22e-653259af07f4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "9ebc6625-fade-41b7-a22e-653259af07f4") },
		{ "1ab4bd3d-2471-48fa-bc82-d5ab024b6f1d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.CompoundStatement), "4fcf185b-e810-4326-aca8-5e1b2a4e442b"}, { new Terminator(KeywordType.Begin), "2972cb43-de3b-4742-a7d8-4dea7f7c4c6e"}, { new NonTerminator(NonTerminatorType.Subprogram), "15a54624-b0e2-4d3e-8d3f-915f65384f05"}, { new NonTerminator(NonTerminatorType.SubprogramHead), "ff4bb880-aad4-49e9-a749-378fa72f3c82"}, { new Terminator(KeywordType.Procedure), "3c220d8c-30c9-4f2c-a55c-9ca597867936"}, { new Terminator(KeywordType.Function), "bf5ac000-c80f-4262-8ed6-788f9caec10a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1ab4bd3d-2471-48fa-bc82-d5ab024b6f1d") },
		{ "6cc5a977-b2f5-450f-9022-a831d1f02804", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "34de596a-d373-42ba-a3b1-05945067cc3d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6cc5a977-b2f5-450f-9022-a831d1f02804") },
		{ "232721fd-a9bb-44be-861f-0e5dc342ccd8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "3de4039d-4e64-4dd4-8225-f10453c25c4b"}, { new Terminator(DelimiterType.Comma), "d7aee9d0-2bdb-435b-93e1-f605ae512af4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "232721fd-a9bb-44be-861f-0e5dc342ccd8") },
		{ "9dc91f71-af68-404e-b670-a90589c075ea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "9dc91f71-af68-404e-b670-a90589c075ea") },
		{ "73839b71-0170-4ed7-b301-cf9520bdde12", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "5bde9e35-03dd-441d-af04-8b1bd47c5cfb"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "73839b71-0170-4ed7-b301-cf9520bdde12") },
		{ "4a53b2fc-7772-49f9-94a8-8a0a37f5e02b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstValue), "11dbb701-abb1-411f-b897-2f47110499fb"}, { new Terminator(OperatorType.Plus), "886299a0-b60e-427c-8aeb-7f294f8bf571"}, { new Terminator(OperatorType.Minus), "5434a693-e276-4d9d-b818-7e167144611a"}, { Terminator.NumberTerminator, "291ecbe9-74dd-45d6-8f3b-35a0d0699df4"}, { new Terminator(DelimiterType.SingleQuotation), "82dcf9dd-612e-45b2-978d-97fb06b3c4c6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4a53b2fc-7772-49f9-94a8-8a0a37f5e02b") },
		{ "f705e5ad-198b-45a7-a2ff-27eace11510f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.ProgramHead))}, }, "f705e5ad-198b-45a7-a2ff-27eace11510f") },
		{ "b4d5eac1-ef91-4843-8ac8-228ccd299991", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "9b310f09-0dd4-40ed-a7f9-272ac1f0c063"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b4d5eac1-ef91-4843-8ac8-228ccd299991") },
		{ "4fcf185b-e810-4326-aca8-5e1b2a4e442b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Period), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProgramBody))}, }, "4fcf185b-e810-4326-aca8-5e1b2a4e442b") },
		{ "2972cb43-de3b-4742-a7d8-4dea7f7c4c6e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "de541851-6d4d-4308-a1c5-a9a6a2fa4ae4"}, { new NonTerminator(NonTerminatorType.Statement), "ab6c0946-5914-4e72-8c12-4b6e7c245045"}, { new NonTerminator(NonTerminatorType.Variable), "112924ad-56a4-4b25-b473-3719cf9f146d"}, { Terminator.IdentifierTerminator, "2ca36d82-352b-460d-9a9c-3820d154ae40"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72"}, { new Terminator(KeywordType.If), "73074719-3be9-46aa-80f3-1e8ee6a9b24b"}, { new Terminator(KeywordType.For), "a53fc2b7-1c76-4892-aefa-96321460277b"}, { new Terminator(KeywordType.Begin), "387138b7-6e8b-4b44-b497-4da7e03d863a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "2972cb43-de3b-4742-a7d8-4dea7f7c4c6e") },
		{ "15a54624-b0e2-4d3e-8d3f-915f65384f05", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "af8eafde-e50f-46bc-b747-a67e16693bee"},}, new Dictionary<Terminator, ReduceInformation>{ }, "15a54624-b0e2-4d3e-8d3f-915f65384f05") },
		{ "ff4bb880-aad4-49e9-a749-378fa72f3c82", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "c6b3e4e8-96e4-4ef3-bfac-6a858f030eef"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ff4bb880-aad4-49e9-a749-378fa72f3c82") },
		{ "3c220d8c-30c9-4f2c-a55c-9ca597867936", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "bbb11ea4-c467-464c-99ef-0cf91c890123"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3c220d8c-30c9-4f2c-a55c-9ca597867936") },
		{ "bf5ac000-c80f-4262-8ed6-788f9caec10a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "470ffe76-12ee-46f9-af28-d4892837b726"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bf5ac000-c80f-4262-8ed6-788f9caec10a") },
		{ "34de596a-d373-42ba-a3b1-05945067cc3d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.IdentifierList), "bb0cab48-5725-4672-9ce7-82bceaa8386a"}, { Terminator.IdentifierTerminator, "9dc91f71-af68-404e-b670-a90589c075ea"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "34de596a-d373-42ba-a3b1-05945067cc3d") },
		{ "3de4039d-4e64-4dd4-8225-f10453c25c4b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Type), "79c4472b-9edb-4602-a84e-654a2a772986"}, { new NonTerminator(NonTerminatorType.BasicType), "99f1a400-2870-4bc4-a665-7ab61eff9dd9"}, { new Terminator(KeywordType.Array), "3cbf837d-e48f-44d0-943e-f5f79706ae8a"}, { new Terminator(KeywordType.Integer), "7a45914c-6e41-40b0-af8d-3aee3f58b52e"}, { new Terminator(KeywordType.Real), "0c324ffd-6717-4e32-84e1-b20373faf37a"}, { new Terminator(KeywordType.Boolean), "2038cb87-ab6e-4cdf-875f-99acab7590d6"}, { new Terminator(KeywordType.Character), "dcf92153-cf0c-4c29-858a-e1ae80990401"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3de4039d-4e64-4dd4-8225-f10453c25c4b") },
		{ "d7aee9d0-2bdb-435b-93e1-f605ae512af4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "3592d1e1-38b1-4571-aa09-49da844e3acc"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d7aee9d0-2bdb-435b-93e1-f605ae512af4") },
		{ "5bde9e35-03dd-441d-af04-8b1bd47c5cfb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Equal), "b03f9c16-0985-46d4-9f4c-6cb91f19ad99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5bde9e35-03dd-441d-af04-8b1bd47c5cfb") },
		{ "11dbb701-abb1-411f-b897-2f47110499fb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclaration))}, }, "11dbb701-abb1-411f-b897-2f47110499fb") },
		{ "886299a0-b60e-427c-8aeb-7f294f8bf571", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "7e17fb4a-f5c5-46c4-89f8-9d01efa480dd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "886299a0-b60e-427c-8aeb-7f294f8bf571") },
		{ "5434a693-e276-4d9d-b818-7e167144611a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "22014225-99f5-49d3-b83c-31b813913b6c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5434a693-e276-4d9d-b818-7e167144611a") },
		{ "291ecbe9-74dd-45d6-8f3b-35a0d0699df4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ConstValue))}, }, "291ecbe9-74dd-45d6-8f3b-35a0d0699df4") },
		{ "82dcf9dd-612e-45b2-978d-97fb06b3c4c6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.CharacterTerminator, "eb16f762-41c1-4a85-804f-b50e53567248"},}, new Dictionary<Terminator, ReduceInformation>{ }, "82dcf9dd-612e-45b2-978d-97fb06b3c4c6") },
		{ "9b310f09-0dd4-40ed-a7f9-272ac1f0c063", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "9b310f09-0dd4-40ed-a7f9-272ac1f0c063") },
		{ "de541851-6d4d-4308-a1c5-a9a6a2fa4ae4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "efdc7526-b350-4015-8efd-16003eba8d9c"}, { new Terminator(DelimiterType.Semicolon), "5f77fc2d-16b7-4de2-aa95-a5b4bf60ead7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "de541851-6d4d-4308-a1c5-a9a6a2fa4ae4") },
		{ "ab6c0946-5914-4e72-8c12-4b6e7c245045", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.StatementList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.StatementList))}, }, "ab6c0946-5914-4e72-8c12-4b6e7c245045") },
		{ "112924ad-56a4-4b25-b473-3719cf9f146d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "3089ff70-d821-4d47-b629-7902c28092b3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "112924ad-56a4-4b25-b473-3719cf9f146d") },
		{ "2ca36d82-352b-460d-9a9c-3820d154ae40", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "ab8a793a-dceb-4979-bedd-9733ce873924"}, { new NonTerminator(NonTerminatorType.IdVarPart), "31eb4679-1bff-483a-9102-7dcbe650e8f6"}, { new Terminator(DelimiterType.LeftSquareBracket), "34b47858-5b58-43b3-85ce-b49447c43b6f"}, { new Terminator(DelimiterType.LeftParenthesis), "6aee9176-caf7-4607-8c83-07df27c90994"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "2ca36d82-352b-460d-9a9c-3820d154ae40") },
		{ "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec") },
		{ "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72") },
		{ "73074719-3be9-46aa-80f3-1e8ee6a9b24b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "f51d5b3c-8c78-47c7-a8d8-e83347cf8236"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "119fac76-96fa-48e8-ac9c-6face14ae1e4"}, { new NonTerminator(NonTerminatorType.Term), "f81767c4-c538-40f6-9d6e-0e0028e43d0a"}, { new NonTerminator(NonTerminatorType.Factor), "fa6197c4-8a18-4901-b9e5-c8a5e9e7d32f"}, { Terminator.NumberTerminator, "d3912ce1-c4e7-4011-8495-39467b183372"}, { new NonTerminator(NonTerminatorType.Variable), "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8"}, { new Terminator(DelimiterType.LeftParenthesis), "136221b1-0def-4616-a331-451c7cd8a042"}, { Terminator.IdentifierTerminator, "f8848d88-5c5c-4719-aa0b-957d66c1b45a"}, { new Terminator(KeywordType.Not), "5415b858-be1e-42df-af7c-df7f5bf4452f"}, { new Terminator(OperatorType.Minus), "d53f38d7-a4c5-4a3d-8821-f702d78332c7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "73074719-3be9-46aa-80f3-1e8ee6a9b24b") },
		{ "a53fc2b7-1c76-4892-aefa-96321460277b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "68ff92a9-820d-455c-bbd7-c833a3da691d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a53fc2b7-1c76-4892-aefa-96321460277b") },
		{ "387138b7-6e8b-4b44-b497-4da7e03d863a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "002712a2-e78c-4d85-b962-4318505609ce"}, { new NonTerminator(NonTerminatorType.Statement), "ab6c0946-5914-4e72-8c12-4b6e7c245045"}, { new NonTerminator(NonTerminatorType.Variable), "112924ad-56a4-4b25-b473-3719cf9f146d"}, { Terminator.IdentifierTerminator, "2ca36d82-352b-460d-9a9c-3820d154ae40"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72"}, { new Terminator(KeywordType.If), "73074719-3be9-46aa-80f3-1e8ee6a9b24b"}, { new Terminator(KeywordType.For), "a53fc2b7-1c76-4892-aefa-96321460277b"}, { new Terminator(KeywordType.Begin), "387138b7-6e8b-4b44-b497-4da7e03d863a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "387138b7-6e8b-4b44-b497-4da7e03d863a") },
		{ "af8eafde-e50f-46bc-b747-a67e16693bee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, }, "af8eafde-e50f-46bc-b747-a67e16693bee") },
		{ "c6b3e4e8-96e4-4ef3-bfac-6a858f030eef", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SubprogramBody), "a3ad216b-5661-4afd-b51b-3c8aa5b15e05"}, { new NonTerminator(NonTerminatorType.ConstDeclarations), "ba747585-1e22-4f50-9324-adcaa0620a94"}, { new Terminator(KeywordType.Const), "9bbeb6e3-e7ec-42e8-8d5f-76e8f0691a52"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "c6b3e4e8-96e4-4ef3-bfac-6a858f030eef") },
		{ "bbb11ea4-c467-464c-99ef-0cf91c890123", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.FormalParameter), "41bbd3f0-e644-4b9c-b32c-6da8b42e3c46"}, { new Terminator(DelimiterType.LeftParenthesis), "7e1faef8-0936-4e9f-ad98-14d50c4712da"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "bbb11ea4-c467-464c-99ef-0cf91c890123") },
		{ "470ffe76-12ee-46f9-af28-d4892837b726", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.FormalParameter), "2b1a4a2a-b924-4275-b22a-0a82441e7e59"}, { new Terminator(DelimiterType.LeftParenthesis), "f154300a-950f-4931-b34a-efd476c81bef"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "470ffe76-12ee-46f9-af28-d4892837b726") },
		{ "bb0cab48-5725-4672-9ce7-82bceaa8386a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "6a803503-1ed2-4eda-8aef-46acc4cc2e4b"}, { new Terminator(DelimiterType.Comma), "d7aee9d0-2bdb-435b-93e1-f605ae512af4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bb0cab48-5725-4672-9ce7-82bceaa8386a") },
		{ "79c4472b-9edb-4602-a84e-654a2a772986", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclaration))}, }, "79c4472b-9edb-4602-a84e-654a2a772986") },
		{ "99f1a400-2870-4bc4-a665-7ab61eff9dd9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Type))}, }, "99f1a400-2870-4bc4-a665-7ab61eff9dd9") },
		{ "3cbf837d-e48f-44d0-943e-f5f79706ae8a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftSquareBracket), "9d6742fe-38a1-4994-930d-88269966cc23"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3cbf837d-e48f-44d0-943e-f5f79706ae8a") },
		{ "7a45914c-6e41-40b0-af8d-3aee3f58b52e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "7a45914c-6e41-40b0-af8d-3aee3f58b52e") },
		{ "0c324ffd-6717-4e32-84e1-b20373faf37a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "0c324ffd-6717-4e32-84e1-b20373faf37a") },
		{ "2038cb87-ab6e-4cdf-875f-99acab7590d6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "2038cb87-ab6e-4cdf-875f-99acab7590d6") },
		{ "dcf92153-cf0c-4c29-858a-e1ae80990401", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "dcf92153-cf0c-4c29-858a-e1ae80990401") },
		{ "3592d1e1-38b1-4571-aa09-49da844e3acc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "3592d1e1-38b1-4571-aa09-49da844e3acc") },
		{ "b03f9c16-0985-46d4-9f4c-6cb91f19ad99", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstValue), "afeb2a41-d58c-4825-85c4-9ac68045151b"}, { new Terminator(OperatorType.Plus), "886299a0-b60e-427c-8aeb-7f294f8bf571"}, { new Terminator(OperatorType.Minus), "5434a693-e276-4d9d-b818-7e167144611a"}, { Terminator.NumberTerminator, "291ecbe9-74dd-45d6-8f3b-35a0d0699df4"}, { new Terminator(DelimiterType.SingleQuotation), "82dcf9dd-612e-45b2-978d-97fb06b3c4c6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b03f9c16-0985-46d4-9f4c-6cb91f19ad99") },
		{ "7e17fb4a-f5c5-46c4-89f8-9d01efa480dd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ConstValue))}, }, "7e17fb4a-f5c5-46c4-89f8-9d01efa480dd") },
		{ "22014225-99f5-49d3-b83c-31b813913b6c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ConstValue))}, }, "22014225-99f5-49d3-b83c-31b813913b6c") },
		{ "eb16f762-41c1-4a85-804f-b50e53567248", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.SingleQuotation), "b767a903-3f8a-4b6e-9561-3b9cf8e17297"},}, new Dictionary<Terminator, ReduceInformation>{ }, "eb16f762-41c1-4a85-804f-b50e53567248") },
		{ "efdc7526-b350-4015-8efd-16003eba8d9c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Period), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "efdc7526-b350-4015-8efd-16003eba8d9c") },
		{ "5f77fc2d-16b7-4de2-aa95-a5b4bf60ead7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "671559f2-ea7c-4806-9237-238b712838ac"}, { new NonTerminator(NonTerminatorType.Variable), "112924ad-56a4-4b25-b473-3719cf9f146d"}, { Terminator.IdentifierTerminator, "2ca36d82-352b-460d-9a9c-3820d154ae40"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72"}, { new Terminator(KeywordType.If), "73074719-3be9-46aa-80f3-1e8ee6a9b24b"}, { new Terminator(KeywordType.For), "a53fc2b7-1c76-4892-aefa-96321460277b"}, { new Terminator(KeywordType.Begin), "387138b7-6e8b-4b44-b497-4da7e03d863a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "5f77fc2d-16b7-4de2-aa95-a5b4bf60ead7") },
		{ "3089ff70-d821-4d47-b629-7902c28092b3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "6964ddd2-21de-4312-a758-5636b143bacd"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "03290228-a79b-4e34-bb13-4024dd4f152a"}, { new NonTerminator(NonTerminatorType.Term), "92777788-9c64-4113-bdd7-43c242cb303b"}, { new NonTerminator(NonTerminatorType.Factor), "36ed9c90-648c-4e06-aceb-ae7234ef4c2a"}, { Terminator.NumberTerminator, "1f8655c6-2b50-4bd5-b8e8-251042ebdf22"}, { new NonTerminator(NonTerminatorType.Variable), "73a82ead-96f2-43d1-be91-b78c04461c8d"}, { new Terminator(DelimiterType.LeftParenthesis), "957917ce-ce2f-484e-9976-367866ffa98a"}, { Terminator.IdentifierTerminator, "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc"}, { new Terminator(KeywordType.Not), "d80ea1cf-f70f-46ce-b045-4e9dedce06cf"}, { new Terminator(OperatorType.Minus), "f1b5949e-6a02-4c6e-85b4-9709080f5c77"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3089ff70-d821-4d47-b629-7902c28092b3") },
		{ "ab8a793a-dceb-4979-bedd-9733ce873924", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "a13444d2-e2f1-401c-affc-149323b976cd"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "03290228-a79b-4e34-bb13-4024dd4f152a"}, { new NonTerminator(NonTerminatorType.Term), "92777788-9c64-4113-bdd7-43c242cb303b"}, { new NonTerminator(NonTerminatorType.Factor), "36ed9c90-648c-4e06-aceb-ae7234ef4c2a"}, { Terminator.NumberTerminator, "1f8655c6-2b50-4bd5-b8e8-251042ebdf22"}, { new NonTerminator(NonTerminatorType.Variable), "73a82ead-96f2-43d1-be91-b78c04461c8d"}, { new Terminator(DelimiterType.LeftParenthesis), "957917ce-ce2f-484e-9976-367866ffa98a"}, { Terminator.IdentifierTerminator, "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc"}, { new Terminator(KeywordType.Not), "d80ea1cf-f70f-46ce-b045-4e9dedce06cf"}, { new Terminator(OperatorType.Minus), "f1b5949e-6a02-4c6e-85b4-9709080f5c77"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ab8a793a-dceb-4979-bedd-9733ce873924") },
		{ "31eb4679-1bff-483a-9102-7dcbe650e8f6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "31eb4679-1bff-483a-9102-7dcbe650e8f6") },
		{ "34b47858-5b58-43b3-85ce-b49447c43b6f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "eb18577b-10bf-4e74-8371-dba96b315d79"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "34b47858-5b58-43b3-85ce-b49447c43b6f") },
		{ "6aee9176-caf7-4607-8c83-07df27c90994", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "54052707-35b5-4878-8797-3805a72670da"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6aee9176-caf7-4607-8c83-07df27c90994") },
		{ "f51d5b3c-8c78-47c7-a8d8-e83347cf8236", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Then), "08352f8e-b7b6-4c3c-a9b5-724c1f011422"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f51d5b3c-8c78-47c7-a8d8-e83347cf8236") },
		{ "119fac76-96fa-48e8-ac9c-6face14ae1e4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "c9c19d32-7795-43b2-87b7-7af407dcf819"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "c5175a48-0bf4-4f9d-9113-c1ed68defb32"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "119fac76-96fa-48e8-ac9c-6face14ae1e4") },
		{ "f81767c4-c538-40f6-9d6e-0e0028e43d0a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "3ee1ab01-482f-42ab-bc07-045e877b8af2"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "f81767c4-c538-40f6-9d6e-0e0028e43d0a") },
		{ "fa6197c4-8a18-4901-b9e5-c8a5e9e7d32f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "fa6197c4-8a18-4901-b9e5-c8a5e9e7d32f") },
		{ "d3912ce1-c4e7-4011-8495-39467b183372", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "d3912ce1-c4e7-4011-8495-39467b183372") },
		{ "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8") },
		{ "136221b1-0def-4616-a331-451c7cd8a042", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "2cb900d3-0c04-4ea9-aa49-2bd7bc0a97a4"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "136221b1-0def-4616-a331-451c7cd8a042") },
		{ "f8848d88-5c5c-4719-aa0b-957d66c1b45a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "f3f17430-4204-4c80-8914-9b91c91d0857"}, { new NonTerminator(NonTerminatorType.IdVarPart), "0e4ecc3e-de64-4a1c-99af-0bdbdc28ba92"}, { new Terminator(DelimiterType.LeftSquareBracket), "05bef34c-aeb8-4cc5-b5f7-d4775d9cdf99"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "f8848d88-5c5c-4719-aa0b-957d66c1b45a") },
		{ "5415b858-be1e-42df-af7c-df7f5bf4452f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "5c2a9c8a-1517-41b6-8ec7-93c885d495e9"}, { Terminator.NumberTerminator, "d3912ce1-c4e7-4011-8495-39467b183372"}, { new NonTerminator(NonTerminatorType.Variable), "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8"}, { new Terminator(DelimiterType.LeftParenthesis), "136221b1-0def-4616-a331-451c7cd8a042"}, { Terminator.IdentifierTerminator, "f8848d88-5c5c-4719-aa0b-957d66c1b45a"}, { new Terminator(KeywordType.Not), "5415b858-be1e-42df-af7c-df7f5bf4452f"}, { new Terminator(OperatorType.Minus), "d53f38d7-a4c5-4a3d-8821-f702d78332c7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5415b858-be1e-42df-af7c-df7f5bf4452f") },
		{ "d53f38d7-a4c5-4a3d-8821-f702d78332c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "c8750fff-2693-4ec6-9b12-c162ec858c2f"}, { Terminator.NumberTerminator, "d3912ce1-c4e7-4011-8495-39467b183372"}, { new NonTerminator(NonTerminatorType.Variable), "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8"}, { new Terminator(DelimiterType.LeftParenthesis), "136221b1-0def-4616-a331-451c7cd8a042"}, { Terminator.IdentifierTerminator, "f8848d88-5c5c-4719-aa0b-957d66c1b45a"}, { new Terminator(KeywordType.Not), "5415b858-be1e-42df-af7c-df7f5bf4452f"}, { new Terminator(OperatorType.Minus), "d53f38d7-a4c5-4a3d-8821-f702d78332c7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d53f38d7-a4c5-4a3d-8821-f702d78332c7") },
		{ "68ff92a9-820d-455c-bbd7-c833a3da691d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "6d40c61c-cc25-4507-b4ff-dd0e87eecd1f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "68ff92a9-820d-455c-bbd7-c833a3da691d") },
		{ "002712a2-e78c-4d85-b962-4318505609ce", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "8a166dc6-8d66-4e96-b949-97382f2b89e9"}, { new Terminator(DelimiterType.Semicolon), "5f77fc2d-16b7-4de2-aa95-a5b4bf60ead7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "002712a2-e78c-4d85-b962-4318505609ce") },
		{ "a3ad216b-5661-4afd-b51b-3c8aa5b15e05", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Subprogram))}, }, "a3ad216b-5661-4afd-b51b-3c8aa5b15e05") },
		{ "ba747585-1e22-4f50-9324-adcaa0620a94", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclarations), "bef9ba6b-d573-4280-954e-20822f48191c"}, { new Terminator(KeywordType.Var), "fc46d9de-be4c-4926-9fb2-dbb70fd7fe64"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "ba747585-1e22-4f50-9324-adcaa0620a94") },
		{ "41bbd3f0-e644-4b9c-b32c-6da8b42e3c46", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramHead))}, }, "41bbd3f0-e644-4b9c-b32c-6da8b42e3c46") },
		{ "7e1faef8-0936-4e9f-ad98-14d50c4712da", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ParameterList), "0180b32a-9241-4ca4-b347-d6531dca4a3c"}, { new NonTerminator(NonTerminatorType.Parameter), "e692fdbb-2566-4e54-ac73-c38c84074eca"}, { new NonTerminator(NonTerminatorType.VarParameter), "a32aefff-0ed1-4bae-a3fd-532141d91533"}, { new NonTerminator(NonTerminatorType.ValueParameter), "01389774-4d1f-4ad4-b947-38167c39ac54"}, { new Terminator(KeywordType.Var), "5a784796-e20c-43c1-baae-86fed3b82835"}, { new NonTerminator(NonTerminatorType.IdentifierList), "20774c5b-8cf2-402f-b07c-95fac09442ec"}, { Terminator.IdentifierTerminator, "9dc91f71-af68-404e-b670-a90589c075ea"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7e1faef8-0936-4e9f-ad98-14d50c4712da") },
		{ "2b1a4a2a-b924-4275-b22a-0a82441e7e59", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "9f04f841-8da4-4eab-8bbb-c48e95a059c0"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2b1a4a2a-b924-4275-b22a-0a82441e7e59") },
		{ "f154300a-950f-4931-b34a-efd476c81bef", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ParameterList), "402c0d68-9a58-445b-b4b0-4f336a49639f"}, { new NonTerminator(NonTerminatorType.Parameter), "e692fdbb-2566-4e54-ac73-c38c84074eca"}, { new NonTerminator(NonTerminatorType.VarParameter), "a32aefff-0ed1-4bae-a3fd-532141d91533"}, { new NonTerminator(NonTerminatorType.ValueParameter), "01389774-4d1f-4ad4-b947-38167c39ac54"}, { new Terminator(KeywordType.Var), "5a784796-e20c-43c1-baae-86fed3b82835"}, { new NonTerminator(NonTerminatorType.IdentifierList), "20774c5b-8cf2-402f-b07c-95fac09442ec"}, { Terminator.IdentifierTerminator, "9dc91f71-af68-404e-b670-a90589c075ea"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f154300a-950f-4931-b34a-efd476c81bef") },
		{ "6a803503-1ed2-4eda-8aef-46acc4cc2e4b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Type), "cce01b45-54b6-47a5-ace8-3d8eb0a3bd89"}, { new NonTerminator(NonTerminatorType.BasicType), "99f1a400-2870-4bc4-a665-7ab61eff9dd9"}, { new Terminator(KeywordType.Array), "3cbf837d-e48f-44d0-943e-f5f79706ae8a"}, { new Terminator(KeywordType.Integer), "7a45914c-6e41-40b0-af8d-3aee3f58b52e"}, { new Terminator(KeywordType.Real), "0c324ffd-6717-4e32-84e1-b20373faf37a"}, { new Terminator(KeywordType.Boolean), "2038cb87-ab6e-4cdf-875f-99acab7590d6"}, { new Terminator(KeywordType.Character), "dcf92153-cf0c-4c29-858a-e1ae80990401"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6a803503-1ed2-4eda-8aef-46acc4cc2e4b") },
		{ "9d6742fe-38a1-4994-930d-88269966cc23", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Period), "a0a3ec7c-bfa6-4073-9cbc-1e2c8ac272ad"}, { Terminator.NumberTerminator, "6e9a3216-99ad-4c55-9e56-060a672f6987"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9d6742fe-38a1-4994-930d-88269966cc23") },
		{ "afeb2a41-d58c-4825-85c4-9ac68045151b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.ConstDeclaration))}, }, "afeb2a41-d58c-4825-85c4-9ac68045151b") },
		{ "b767a903-3f8a-4b6e-9561-3b9cf8e17297", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstValue))}, }, "b767a903-3f8a-4b6e-9561-3b9cf8e17297") },
		{ "671559f2-ea7c-4806-9237-238b712838ac", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.StatementList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.StatementList))}, }, "671559f2-ea7c-4806-9237-238b712838ac") },
		{ "6964ddd2-21de-4312-a758-5636b143bacd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "6964ddd2-21de-4312-a758-5636b143bacd") },
		{ "03290228-a79b-4e34-bb13-4024dd4f152a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "587568c7-1b64-46d0-94e8-9c2693454e15"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "d356e915-8afb-44c3-84bf-5783b67c1d30"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "03290228-a79b-4e34-bb13-4024dd4f152a") },
		{ "92777788-9c64-4113-bdd7-43c242cb303b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "51e2b277-c6f5-44be-87d5-d64c1466d57b"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "92777788-9c64-4113-bdd7-43c242cb303b") },
		{ "36ed9c90-648c-4e06-aceb-ae7234ef4c2a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "36ed9c90-648c-4e06-aceb-ae7234ef4c2a") },
		{ "1f8655c6-2b50-4bd5-b8e8-251042ebdf22", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "1f8655c6-2b50-4bd5-b8e8-251042ebdf22") },
		{ "73a82ead-96f2-43d1-be91-b78c04461c8d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "73a82ead-96f2-43d1-be91-b78c04461c8d") },
		{ "957917ce-ce2f-484e-9976-367866ffa98a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "370e9618-4a09-4052-be4d-fc2efcd08d78"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "957917ce-ce2f-484e-9976-367866ffa98a") },
		{ "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "40f3183a-a745-47d8-a114-f4f1ccec776c"}, { new NonTerminator(NonTerminatorType.IdVarPart), "dd775686-9a26-48ff-863f-bf7225259cb1"}, { new Terminator(DelimiterType.LeftSquareBracket), "4d9fbec3-1c8c-4b07-9093-a03b4853bdc9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc") },
		{ "d80ea1cf-f70f-46ce-b045-4e9dedce06cf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "4e50f4ac-349b-4e94-8045-b35186b6d9d9"}, { Terminator.NumberTerminator, "1f8655c6-2b50-4bd5-b8e8-251042ebdf22"}, { new NonTerminator(NonTerminatorType.Variable), "73a82ead-96f2-43d1-be91-b78c04461c8d"}, { new Terminator(DelimiterType.LeftParenthesis), "957917ce-ce2f-484e-9976-367866ffa98a"}, { Terminator.IdentifierTerminator, "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc"}, { new Terminator(KeywordType.Not), "d80ea1cf-f70f-46ce-b045-4e9dedce06cf"}, { new Terminator(OperatorType.Minus), "f1b5949e-6a02-4c6e-85b4-9709080f5c77"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d80ea1cf-f70f-46ce-b045-4e9dedce06cf") },
		{ "f1b5949e-6a02-4c6e-85b4-9709080f5c77", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "ba8d5823-93e7-4eac-86bd-98629ebf79a1"}, { Terminator.NumberTerminator, "1f8655c6-2b50-4bd5-b8e8-251042ebdf22"}, { new NonTerminator(NonTerminatorType.Variable), "73a82ead-96f2-43d1-be91-b78c04461c8d"}, { new Terminator(DelimiterType.LeftParenthesis), "957917ce-ce2f-484e-9976-367866ffa98a"}, { Terminator.IdentifierTerminator, "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc"}, { new Terminator(KeywordType.Not), "d80ea1cf-f70f-46ce-b045-4e9dedce06cf"}, { new Terminator(OperatorType.Minus), "f1b5949e-6a02-4c6e-85b4-9709080f5c77"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f1b5949e-6a02-4c6e-85b4-9709080f5c77") },
		{ "a13444d2-e2f1-401c-affc-149323b976cd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "a13444d2-e2f1-401c-affc-149323b976cd") },
		{ "eb18577b-10bf-4e74-8371-dba96b315d79", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "58229ff1-3a27-45c0-8591-46da875972ce"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "eb18577b-10bf-4e74-8371-dba96b315d79") },
		{ "09cac309-abed-414e-8474-6b60d13f6cfa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "09cac309-abed-414e-8474-6b60d13f6cfa") },
		{ "bccb9e4b-0144-4242-9be0-44e084fa0288", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "bfd3903b-2789-41f1-9399-70fa704acc26"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "ec7b7c00-0bbf-496d-be76-f6333cd35721"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "bccb9e4b-0144-4242-9be0-44e084fa0288") },
		{ "71aebecb-07f7-4c81-835c-c9d30e8c591c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "de1cc3ab-1a1e-4a3e-99ee-ee6161b1eff2"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "71aebecb-07f7-4c81-835c-c9d30e8c591c") },
		{ "c912911e-3115-461e-a0b0-8a928d65964f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "c912911e-3115-461e-a0b0-8a928d65964f") },
		{ "f73caf00-2936-4127-8f89-315d90db052b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "f73caf00-2936-4127-8f89-315d90db052b") },
		{ "ba1ee670-0706-4663-b78a-af6dc5c23f48", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "ba1ee670-0706-4663-b78a-af6dc5c23f48") },
		{ "2a561d9c-4157-4dc7-be4c-4d914f111ffe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "e9d851d4-b8ec-48fe-90a0-7ed14e292642"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2a561d9c-4157-4dc7-be4c-4d914f111ffe") },
		{ "041f60de-3c2b-4aaf-8284-b02aa5db505f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "365c89ce-559a-4a97-b250-957266a0cf6a"}, { new NonTerminator(NonTerminatorType.IdVarPart), "602edddc-0ea9-4205-8015-522baa4cd334"}, { new Terminator(DelimiterType.LeftSquareBracket), "f056f56a-f9ca-4bd4-b13e-222864357355"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "041f60de-3c2b-4aaf-8284-b02aa5db505f") },
		{ "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "faeaa1f3-9cd6-4e00-9b44-0da1ffd0e75c"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c") },
		{ "7928c972-6f98-47d1-a422-bdd087c5c11e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "24082fea-b33b-4e50-bf87-79e84f3fff04"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7928c972-6f98-47d1-a422-bdd087c5c11e") },
		{ "54052707-35b5-4878-8797-3805a72670da", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "abb037b1-6d15-47a7-8cda-ce5715b54275"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "54052707-35b5-4878-8797-3805a72670da") },
		{ "48274443-b7c1-435d-aaaa-8a09601273f9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "48274443-b7c1-435d-aaaa-8a09601273f9") },
		{ "86f8df3e-3b19-48fe-a2cd-34bc036a4d16", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "886724dd-02ce-4b9e-ba5d-2aa122847195"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "1e5f9ce4-ae96-4405-aa6f-1bbdb7e280d3"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "86f8df3e-3b19-48fe-a2cd-34bc036a4d16") },
		{ "2db80379-6dfa-40eb-9c52-02ab09351164", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "90863c9b-ac16-49a4-93f3-65cb3507c4c1"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "2db80379-6dfa-40eb-9c52-02ab09351164") },
		{ "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d") },
		{ "12f3cddc-f277-4425-9eca-38884494e86e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "12f3cddc-f277-4425-9eca-38884494e86e") },
		{ "87838683-e4f8-4027-88ee-75bc41d6c7d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "87838683-e4f8-4027-88ee-75bc41d6c7d3") },
		{ "94925daf-54ea-4162-ae04-0fa6bb913c83", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "837cb9ad-c86d-4c94-ad78-260aca195fab"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "94925daf-54ea-4162-ae04-0fa6bb913c83") },
		{ "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "2802aad2-6f0b-418b-8d28-bf3d4b24719c"}, { new NonTerminator(NonTerminatorType.IdVarPart), "18c58b86-5cc2-407f-b6ff-4ac548af8538"}, { new Terminator(DelimiterType.LeftSquareBracket), "439f0610-f1f7-404e-9458-7cc32c8c61b9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f") },
		{ "4f30dea8-6760-46df-809f-f6b6474b2c8b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "4f35f236-abc1-455c-ab8e-23542734b697"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4f30dea8-6760-46df-809f-f6b6474b2c8b") },
		{ "5dceebf4-1f3b-4767-b816-cf24661377ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "26ed1292-26fd-42d4-a528-7071b4810d16"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5dceebf4-1f3b-4767-b816-cf24661377ff") },
		{ "08352f8e-b7b6-4c3c-a9b5-724c1f011422", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "3a36c7aa-ec86-4347-a3b2-f786918cb578"}, { new NonTerminator(NonTerminatorType.Variable), "05c3dea6-abe5-485c-8fa4-9e7a2af0498c"}, { Terminator.IdentifierTerminator, "bf56ce79-ff0a-4859-b78f-d27987ca5b26"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "36a10a85-e2d6-4119-9b5a-21b6d9fa8c7d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "b9faa148-d99c-4da2-90bd-dc5cc36c5687"}, { new Terminator(KeywordType.If), "cc979e47-296d-4fda-82eb-96b5a942102a"}, { new Terminator(KeywordType.For), "84cd7591-19e5-4b45-be6d-22625f85cf37"}, { new Terminator(KeywordType.Begin), "8d7a1805-2634-4dc3-95e4-15207f4d8e1f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "08352f8e-b7b6-4c3c-a9b5-724c1f011422") },
		{ "c9c19d32-7795-43b2-87b7-7af407dcf819", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "f37d6d6e-a5a0-44ab-acef-86be9430fd0c"}, { new NonTerminator(NonTerminatorType.Term), "590ddc2c-38fb-400e-a176-b5f385ff88da"}, { new NonTerminator(NonTerminatorType.Factor), "679ddcb5-a245-40ec-9fae-2b0973d2ffd5"}, { Terminator.NumberTerminator, "e003a9f9-5fe2-4fa3-a274-aab8ca366a67"}, { new NonTerminator(NonTerminatorType.Variable), "fdb989a1-5f23-4da1-8cbb-76edef766de2"}, { new Terminator(DelimiterType.LeftParenthesis), "a10bbe8d-d2ae-4e67-9536-341e82afda65"}, { Terminator.IdentifierTerminator, "2c41f32f-55b0-4ac7-8de9-3f33225a8bde"}, { new Terminator(KeywordType.Not), "6faa6c27-ef28-475e-bc81-7df55e5b749e"}, { new Terminator(OperatorType.Minus), "3c6d2331-578b-4df7-97af-139b9b6881b9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c9c19d32-7795-43b2-87b7-7af407dcf819") },
		{ "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a") },
		{ "4e399383-d018-47f4-87d5-2418bf4b6b29", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "4e399383-d018-47f4-87d5-2418bf4b6b29") },
		{ "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4") },
		{ "cf782124-1ea5-49aa-a517-45fa0ab10178", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "cf782124-1ea5-49aa-a517-45fa0ab10178") },
		{ "75215ba5-2f7f-4b58-a20a-4128349739eb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "75215ba5-2f7f-4b58-a20a-4128349739eb") },
		{ "1e7ec66b-82ce-4ccf-860c-5162c9565f7d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "1e7ec66b-82ce-4ccf-860c-5162c9565f7d") },
		{ "c5175a48-0bf4-4f9d-9113-c1ed68defb32", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "979ef50b-7dc5-43b7-8f49-0cb3b9317a33"}, { new NonTerminator(NonTerminatorType.Factor), "fa6197c4-8a18-4901-b9e5-c8a5e9e7d32f"}, { Terminator.NumberTerminator, "d3912ce1-c4e7-4011-8495-39467b183372"}, { new NonTerminator(NonTerminatorType.Variable), "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8"}, { new Terminator(DelimiterType.LeftParenthesis), "136221b1-0def-4616-a331-451c7cd8a042"}, { Terminator.IdentifierTerminator, "f8848d88-5c5c-4719-aa0b-957d66c1b45a"}, { new Terminator(KeywordType.Not), "5415b858-be1e-42df-af7c-df7f5bf4452f"}, { new Terminator(OperatorType.Minus), "d53f38d7-a4c5-4a3d-8821-f702d78332c7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c5175a48-0bf4-4f9d-9113-c1ed68defb32") },
		{ "38822c33-4ba5-4392-ba95-563f93b165e7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "38822c33-4ba5-4392-ba95-563f93b165e7") },
		{ "6f247b41-6a05-41b6-9d79-ead414b3e4c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "6f247b41-6a05-41b6-9d79-ead414b3e4c7") },
		{ "3c259c6f-e75c-4280-b176-95d6a084bd3d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "3c259c6f-e75c-4280-b176-95d6a084bd3d") },
		{ "3ee1ab01-482f-42ab-bc07-045e877b8af2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "f9699208-5852-415f-8044-9569213d0673"}, { Terminator.NumberTerminator, "d3912ce1-c4e7-4011-8495-39467b183372"}, { new NonTerminator(NonTerminatorType.Variable), "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8"}, { new Terminator(DelimiterType.LeftParenthesis), "136221b1-0def-4616-a331-451c7cd8a042"}, { Terminator.IdentifierTerminator, "f8848d88-5c5c-4719-aa0b-957d66c1b45a"}, { new Terminator(KeywordType.Not), "5415b858-be1e-42df-af7c-df7f5bf4452f"}, { new Terminator(OperatorType.Minus), "d53f38d7-a4c5-4a3d-8821-f702d78332c7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3ee1ab01-482f-42ab-bc07-045e877b8af2") },
		{ "468d595b-f6df-4fdb-bb63-a555c3440509", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "468d595b-f6df-4fdb-bb63-a555c3440509") },
		{ "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993") },
		{ "6058f285-f42b-4688-8991-89f53d3b025a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "6058f285-f42b-4688-8991-89f53d3b025a") },
		{ "4b86a3b2-9a85-4208-be25-5fc3f6e8a868", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "4b86a3b2-9a85-4208-be25-5fc3f6e8a868") },
		{ "3622ef10-e09f-47d6-a683-b9ae2016733c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "3622ef10-e09f-47d6-a683-b9ae2016733c") },
		{ "2cb900d3-0c04-4ea9-aa49-2bd7bc0a97a4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "0dee96e1-f930-4027-9d8d-ceea7c2a49b7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2cb900d3-0c04-4ea9-aa49-2bd7bc0a97a4") },
		{ "079b7b79-612b-4966-9a45-a29921890ddc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "fc0fb8d7-393d-4607-b11a-3b1f553b4390"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "4030816f-3e3a-44a3-85cb-9775d5218d41"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "079b7b79-612b-4966-9a45-a29921890ddc") },
		{ "64ca8901-7e44-43f8-aa05-19618ec7272e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "a6c954e2-cd1d-4f2a-a59a-49f6cde2886c"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "64ca8901-7e44-43f8-aa05-19618ec7272e") },
		{ "87a8bb69-0783-4472-a058-62990d79c1e7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "87a8bb69-0783-4472-a058-62990d79c1e7") },
		{ "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de") },
		{ "ed2faab9-002b-4f70-a59d-4b6545a4c182", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "ed2faab9-002b-4f70-a59d-4b6545a4c182") },
		{ "473cdb76-aded-49c1-83cf-f8f138d8133a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "41696f89-d4f3-4f8a-b856-21e954879f7d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "473cdb76-aded-49c1-83cf-f8f138d8133a") },
		{ "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "e4c3489e-d8c3-45ac-ba55-7a0fca7975d7"}, { new NonTerminator(NonTerminatorType.IdVarPart), "32ed1aea-aa0a-4129-8e95-f6a8bb02d932"}, { new Terminator(DelimiterType.LeftSquareBracket), "bc957a92-9eb8-47ef-84c6-83f63fb97172"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0") },
		{ "b9e61a85-f306-47f3-816b-781c46782d33", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "5b6ebe5c-8f61-4cd2-bd66-641bbbc22fc2"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b9e61a85-f306-47f3-816b-781c46782d33") },
		{ "cdd3a5b5-1547-4278-b7d6-3f830faa954b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "32d8e07e-48db-4bc7-98d3-ca91dc922594"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cdd3a5b5-1547-4278-b7d6-3f830faa954b") },
		{ "f3f17430-4204-4c80-8914-9b91c91d0857", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "8611a6fa-68d1-4dfc-a264-d0407d3fa04f"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f3f17430-4204-4c80-8914-9b91c91d0857") },
		{ "0e4ecc3e-de64-4a1c-99af-0bdbdc28ba92", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "0e4ecc3e-de64-4a1c-99af-0bdbdc28ba92") },
		{ "05bef34c-aeb8-4cc5-b5f7-d4775d9cdf99", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "2bd2926f-8578-481c-ac28-5e5c8d277acf"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "05bef34c-aeb8-4cc5-b5f7-d4775d9cdf99") },
		{ "5c2a9c8a-1517-41b6-8ec7-93c885d495e9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "5c2a9c8a-1517-41b6-8ec7-93c885d495e9") },
		{ "c8750fff-2693-4ec6-9b12-c162ec858c2f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "c8750fff-2693-4ec6-9b12-c162ec858c2f") },
		{ "6d40c61c-cc25-4507-b4ff-dd0e87eecd1f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "8aacceed-0a42-4770-b4fc-7d6dd34a87c2"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b6a5494-2343-448c-992f-4570f3f4dc73"}, { new NonTerminator(NonTerminatorType.Term), "cdfef4a8-4523-4b63-aff2-e92c2bf95cb4"}, { new NonTerminator(NonTerminatorType.Factor), "31efe073-cd8d-4d8b-8cab-33d1e7775d29"}, { Terminator.NumberTerminator, "9047140a-81c6-48cb-b552-3e72ff88039f"}, { new NonTerminator(NonTerminatorType.Variable), "b783bbe2-0d69-4647-b122-4dcbb03b97ac"}, { new Terminator(DelimiterType.LeftParenthesis), "a4e3b184-75b6-4f8b-8606-030803eb6125"}, { Terminator.IdentifierTerminator, "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69"}, { new Terminator(KeywordType.Not), "36de7783-58bd-4876-8056-1266ff3c75e9"}, { new Terminator(OperatorType.Minus), "62b09801-8689-4fff-9636-b6ac02ab3307"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6d40c61c-cc25-4507-b4ff-dd0e87eecd1f") },
		{ "8a166dc6-8d66-4e96-b949-97382f2b89e9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "8a166dc6-8d66-4e96-b949-97382f2b89e9") },
		{ "bef9ba6b-d573-4280-954e-20822f48191c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.CompoundStatement), "e2df2d84-ec0c-481b-af32-4b05d46a1508"}, { new Terminator(KeywordType.Begin), "0a15b54e-4f7f-450f-bc23-205961ec10cc"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bef9ba6b-d573-4280-954e-20822f48191c") },
		{ "0180b32a-9241-4ca4-b347-d6531dca4a3c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "7b1ed636-1796-452c-a6fb-e9c18431602f"}, { new Terminator(DelimiterType.Semicolon), "128773d3-b196-452b-be82-b6cc25d7d18e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0180b32a-9241-4ca4-b347-d6531dca4a3c") },
		{ "e692fdbb-2566-4e54-ac73-c38c84074eca", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ParameterList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ParameterList))}, }, "e692fdbb-2566-4e54-ac73-c38c84074eca") },
		{ "a32aefff-0ed1-4bae-a3fd-532141d91533", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, }, "a32aefff-0ed1-4bae-a3fd-532141d91533") },
		{ "01389774-4d1f-4ad4-b947-38167c39ac54", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, }, "01389774-4d1f-4ad4-b947-38167c39ac54") },
		{ "5a784796-e20c-43c1-baae-86fed3b82835", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ValueParameter), "f01c147f-deea-49bb-a366-37349c1030a5"}, { new NonTerminator(NonTerminatorType.IdentifierList), "20774c5b-8cf2-402f-b07c-95fac09442ec"}, { Terminator.IdentifierTerminator, "9dc91f71-af68-404e-b670-a90589c075ea"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5a784796-e20c-43c1-baae-86fed3b82835") },
		{ "20774c5b-8cf2-402f-b07c-95fac09442ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "f8c3fc05-b87e-429f-8744-6b62a965e6f3"}, { new Terminator(DelimiterType.Comma), "d7aee9d0-2bdb-435b-93e1-f605ae512af4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "20774c5b-8cf2-402f-b07c-95fac09442ec") },
		{ "9f04f841-8da4-4eab-8bbb-c48e95a059c0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "f7a87078-4f16-49b0-b230-830899dadd1e"}, { new Terminator(KeywordType.Integer), "7a45914c-6e41-40b0-af8d-3aee3f58b52e"}, { new Terminator(KeywordType.Real), "0c324ffd-6717-4e32-84e1-b20373faf37a"}, { new Terminator(KeywordType.Boolean), "2038cb87-ab6e-4cdf-875f-99acab7590d6"}, { new Terminator(KeywordType.Character), "dcf92153-cf0c-4c29-858a-e1ae80990401"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9f04f841-8da4-4eab-8bbb-c48e95a059c0") },
		{ "402c0d68-9a58-445b-b4b0-4f336a49639f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "9bca897d-cab6-46c1-a5b8-04e8f2648e0b"}, { new Terminator(DelimiterType.Semicolon), "128773d3-b196-452b-be82-b6cc25d7d18e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "402c0d68-9a58-445b-b4b0-4f336a49639f") },
		{ "cce01b45-54b6-47a5-ace8-3d8eb0a3bd89", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.VarDeclaration))}, }, "cce01b45-54b6-47a5-ace8-3d8eb0a3bd89") },
		{ "a0a3ec7c-bfa6-4073-9cbc-1e2c8ac272ad", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "25bcf90d-f787-4fd7-a28e-09954ce654b4"}, { new Terminator(DelimiterType.Comma), "08886912-7926-4ec7-ac86-622d47bf68c4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a0a3ec7c-bfa6-4073-9cbc-1e2c8ac272ad") },
		{ "6e9a3216-99ad-4c55-9e56-060a672f6987", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.DoubleDots), "5cc8eda1-6e2c-43c7-acfa-115b42602420"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6e9a3216-99ad-4c55-9e56-060a672f6987") },
		{ "587568c7-1b64-46d0-94e8-9c2693454e15", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "80016048-6472-4366-a565-27de66e9c648"}, { new NonTerminator(NonTerminatorType.Term), "7f4f76d2-aef6-4155-afa0-9234ed9f08cb"}, { new NonTerminator(NonTerminatorType.Factor), "6a24b40f-d563-4fbb-b93c-93e65232d665"}, { Terminator.NumberTerminator, "d3d7b60e-4bab-41a7-9df1-b34e21d63fdf"}, { new NonTerminator(NonTerminatorType.Variable), "09285f9d-9cb9-456e-b569-c95a72695c3b"}, { new Terminator(DelimiterType.LeftParenthesis), "7b921bae-b232-40cb-9431-0a4935fdda35"}, { Terminator.IdentifierTerminator, "615f7cdf-2a33-4f13-a3d0-c52709d8fb14"}, { new Terminator(KeywordType.Not), "c2c51c07-8e89-40fe-8d4a-b3ba2f43fd16"}, { new Terminator(OperatorType.Minus), "61c1af47-267f-4eec-82c4-8b857addf262"},}, new Dictionary<Terminator, ReduceInformation>{ }, "587568c7-1b64-46d0-94e8-9c2693454e15") },
		{ "d356e915-8afb-44c3-84bf-5783b67c1d30", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "16ecf6a3-5cd8-42f7-b4f3-0823e9686e6d"}, { new NonTerminator(NonTerminatorType.Factor), "36ed9c90-648c-4e06-aceb-ae7234ef4c2a"}, { Terminator.NumberTerminator, "1f8655c6-2b50-4bd5-b8e8-251042ebdf22"}, { new NonTerminator(NonTerminatorType.Variable), "73a82ead-96f2-43d1-be91-b78c04461c8d"}, { new Terminator(DelimiterType.LeftParenthesis), "957917ce-ce2f-484e-9976-367866ffa98a"}, { Terminator.IdentifierTerminator, "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc"}, { new Terminator(KeywordType.Not), "d80ea1cf-f70f-46ce-b045-4e9dedce06cf"}, { new Terminator(OperatorType.Minus), "f1b5949e-6a02-4c6e-85b4-9709080f5c77"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d356e915-8afb-44c3-84bf-5783b67c1d30") },
		{ "51e2b277-c6f5-44be-87d5-d64c1466d57b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "77169fff-57ea-4eee-8ff1-9cfc311747e0"}, { Terminator.NumberTerminator, "1f8655c6-2b50-4bd5-b8e8-251042ebdf22"}, { new NonTerminator(NonTerminatorType.Variable), "73a82ead-96f2-43d1-be91-b78c04461c8d"}, { new Terminator(DelimiterType.LeftParenthesis), "957917ce-ce2f-484e-9976-367866ffa98a"}, { Terminator.IdentifierTerminator, "f83fe52e-9f6c-469b-92db-35d7ea1c5ecc"}, { new Terminator(KeywordType.Not), "d80ea1cf-f70f-46ce-b045-4e9dedce06cf"}, { new Terminator(OperatorType.Minus), "f1b5949e-6a02-4c6e-85b4-9709080f5c77"},}, new Dictionary<Terminator, ReduceInformation>{ }, "51e2b277-c6f5-44be-87d5-d64c1466d57b") },
		{ "370e9618-4a09-4052-be4d-fc2efcd08d78", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "f014e20b-4084-40d1-8a1d-ffce04d50197"},}, new Dictionary<Terminator, ReduceInformation>{ }, "370e9618-4a09-4052-be4d-fc2efcd08d78") },
		{ "40f3183a-a745-47d8-a114-f4f1ccec776c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "53f8abc4-8569-4f94-8714-730a9b6ed96e"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "40f3183a-a745-47d8-a114-f4f1ccec776c") },
		{ "dd775686-9a26-48ff-863f-bf7225259cb1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "dd775686-9a26-48ff-863f-bf7225259cb1") },
		{ "4d9fbec3-1c8c-4b07-9093-a03b4853bdc9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "ac6f4d9d-f19a-4fef-bc01-6bb0ad771565"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4d9fbec3-1c8c-4b07-9093-a03b4853bdc9") },
		{ "4e50f4ac-349b-4e94-8045-b35186b6d9d9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "4e50f4ac-349b-4e94-8045-b35186b6d9d9") },
		{ "ba8d5823-93e7-4eac-86bd-98629ebf79a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "ba8d5823-93e7-4eac-86bd-98629ebf79a1") },
		{ "58229ff1-3a27-45c0-8591-46da875972ce", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "58229ff1-3a27-45c0-8591-46da875972ce") },
		{ "a26b6e4c-56b3-4f5a-b969-ae4555e304a6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "2764259e-46a1-4042-b120-96622c169496"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a26b6e4c-56b3-4f5a-b969-ae4555e304a6") },
		{ "bfd3903b-2789-41f1-9399-70fa704acc26", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "368d4fe6-f7ec-4bbd-a1fd-8394de0a6994"}, { new NonTerminator(NonTerminatorType.Term), "2af15985-274c-494e-8006-04d1e56c434b"}, { new NonTerminator(NonTerminatorType.Factor), "f6afc2a2-d7cf-45f9-b1e3-347690927214"}, { Terminator.NumberTerminator, "d92561e5-ab5f-46f9-bdf0-12691df87dc5"}, { new NonTerminator(NonTerminatorType.Variable), "a2d65047-b87e-423f-b1cf-59c048ad7daa"}, { new Terminator(DelimiterType.LeftParenthesis), "3c1034e3-0d98-4c46-9df4-5376b518de2c"}, { Terminator.IdentifierTerminator, "85889ca5-6e30-4bcc-8282-c72224ec8608"}, { new Terminator(KeywordType.Not), "c94499cc-f088-48d3-93e8-0da61332b846"}, { new Terminator(OperatorType.Minus), "7e0f0929-19f3-42a8-b568-878a7b81617e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bfd3903b-2789-41f1-9399-70fa704acc26") },
		{ "ec7b7c00-0bbf-496d-be76-f6333cd35721", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "7a5cb99c-2567-4f4a-9bd2-efc049c1eaf7"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ec7b7c00-0bbf-496d-be76-f6333cd35721") },
		{ "de1cc3ab-1a1e-4a3e-99ee-ee6161b1eff2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e9d6db93-4578-466f-8b5c-fe98530c8a05"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "de1cc3ab-1a1e-4a3e-99ee-ee6161b1eff2") },
		{ "e9d851d4-b8ec-48fe-90a0-7ed14e292642", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "e8700800-7eee-4eba-a1a7-2a7d471187bc"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e9d851d4-b8ec-48fe-90a0-7ed14e292642") },
		{ "365c89ce-559a-4a97-b250-957266a0cf6a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "cd499a9c-5961-4cc1-b4c8-45b82d390499"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "365c89ce-559a-4a97-b250-957266a0cf6a") },
		{ "602edddc-0ea9-4205-8015-522baa4cd334", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "602edddc-0ea9-4205-8015-522baa4cd334") },
		{ "f056f56a-f9ca-4bd4-b13e-222864357355", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "ce59817f-d8ad-4a9b-b0a7-a37e18618e62"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f056f56a-f9ca-4bd4-b13e-222864357355") },
		{ "faeaa1f3-9cd6-4e00-9b44-0da1ffd0e75c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "faeaa1f3-9cd6-4e00-9b44-0da1ffd0e75c") },
		{ "24082fea-b33b-4e50-bf87-79e84f3fff04", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "24082fea-b33b-4e50-bf87-79e84f3fff04") },
		{ "abb037b1-6d15-47a7-8cda-ce5715b54275", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "abb037b1-6d15-47a7-8cda-ce5715b54275") },
		{ "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "6d14ee42-1f5e-40c1-914e-607b6c5f1e24"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7") },
		{ "886724dd-02ce-4b9e-ba5d-2aa122847195", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "4158fa98-635d-4a63-88ec-7f3037df1aa9"}, { new NonTerminator(NonTerminatorType.Term), "d39336cb-35d8-44d2-b35b-548a3ac7a15f"}, { new NonTerminator(NonTerminatorType.Factor), "55259b52-bdfa-4c54-80f0-8882489977a7"}, { Terminator.NumberTerminator, "17272e2b-9263-42c1-bcfa-59955b608bdd"}, { new NonTerminator(NonTerminatorType.Variable), "ac7e5cb8-938b-47eb-aac5-d550639bec19"}, { new Terminator(DelimiterType.LeftParenthesis), "9c2fa58e-138d-4b14-9b14-9578f2fb0c6a"}, { Terminator.IdentifierTerminator, "236624af-bfe0-4a02-b536-b5f86c53bd35"}, { new Terminator(KeywordType.Not), "7c9dfa64-f1dd-46aa-9839-3d31f42f0192"}, { new Terminator(OperatorType.Minus), "404a3540-776d-4af0-a69b-e62dba9820d2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "886724dd-02ce-4b9e-ba5d-2aa122847195") },
		{ "1e5f9ce4-ae96-4405-aa6f-1bbdb7e280d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "ee316822-0e3c-473c-a087-0591592be4c3"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1e5f9ce4-ae96-4405-aa6f-1bbdb7e280d3") },
		{ "90863c9b-ac16-49a4-93f3-65cb3507c4c1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "53e3a8ab-2719-4f80-b1dc-fb8c168e87fb"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "90863c9b-ac16-49a4-93f3-65cb3507c4c1") },
		{ "837cb9ad-c86d-4c94-ad78-260aca195fab", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "727a6a40-ca19-4f5e-b344-3749c08fd86e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "837cb9ad-c86d-4c94-ad78-260aca195fab") },
		{ "2802aad2-6f0b-418b-8d28-bf3d4b24719c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "a2c3f894-e8ca-490b-bcf0-0ba2bec3ba02"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2802aad2-6f0b-418b-8d28-bf3d4b24719c") },
		{ "18c58b86-5cc2-407f-b6ff-4ac548af8538", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "18c58b86-5cc2-407f-b6ff-4ac548af8538") },
		{ "439f0610-f1f7-404e-9458-7cc32c8c61b9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "a57f78cd-0cfb-49cc-b6f9-7c290c2db7ed"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "439f0610-f1f7-404e-9458-7cc32c8c61b9") },
		{ "4f35f236-abc1-455c-ab8e-23542734b697", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "4f35f236-abc1-455c-ab8e-23542734b697") },
		{ "26ed1292-26fd-42d4-a528-7071b4810d16", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "26ed1292-26fd-42d4-a528-7071b4810d16") },
		{ "3a36c7aa-ec86-4347-a3b2-f786918cb578", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ElsePart), "ee93c3b1-f118-46e9-a12c-6e4fafda9a32"}, { new Terminator(KeywordType.Else), "bbde4b09-6361-4cd1-b448-0c3193f11586"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, }, "3a36c7aa-ec86-4347-a3b2-f786918cb578") },
		{ "05c3dea6-abe5-485c-8fa4-9e7a2af0498c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "c4a65452-2c63-4ae0-9f17-d748e6ce410b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "05c3dea6-abe5-485c-8fa4-9e7a2af0498c") },
		{ "bf56ce79-ff0a-4859-b78f-d27987ca5b26", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "f5aafea0-87c3-4a9e-bd84-e79e65671bc1"}, { new NonTerminator(NonTerminatorType.IdVarPart), "31eb4679-1bff-483a-9102-7dcbe650e8f6"}, { new Terminator(DelimiterType.LeftSquareBracket), "34b47858-5b58-43b3-85ce-b49447c43b6f"}, { new Terminator(DelimiterType.LeftParenthesis), "4f0710b6-1b96-4b80-a239-e70be7c44b4e"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "bf56ce79-ff0a-4859-b78f-d27987ca5b26") },
		{ "36a10a85-e2d6-4119-9b5a-21b6d9fa8c7d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "36a10a85-e2d6-4119-9b5a-21b6d9fa8c7d") },
		{ "b9faa148-d99c-4da2-90bd-dc5cc36c5687", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "b9faa148-d99c-4da2-90bd-dc5cc36c5687") },
		{ "cc979e47-296d-4fda-82eb-96b5a942102a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "df85ff83-ff09-44ca-9c1f-699bf73f9f32"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "119fac76-96fa-48e8-ac9c-6face14ae1e4"}, { new NonTerminator(NonTerminatorType.Term), "f81767c4-c538-40f6-9d6e-0e0028e43d0a"}, { new NonTerminator(NonTerminatorType.Factor), "fa6197c4-8a18-4901-b9e5-c8a5e9e7d32f"}, { Terminator.NumberTerminator, "d3912ce1-c4e7-4011-8495-39467b183372"}, { new NonTerminator(NonTerminatorType.Variable), "da07c5e4-2d98-4b01-9973-0fd8b68c6fa8"}, { new Terminator(DelimiterType.LeftParenthesis), "136221b1-0def-4616-a331-451c7cd8a042"}, { Terminator.IdentifierTerminator, "f8848d88-5c5c-4719-aa0b-957d66c1b45a"}, { new Terminator(KeywordType.Not), "5415b858-be1e-42df-af7c-df7f5bf4452f"}, { new Terminator(OperatorType.Minus), "d53f38d7-a4c5-4a3d-8821-f702d78332c7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cc979e47-296d-4fda-82eb-96b5a942102a") },
		{ "84cd7591-19e5-4b45-be6d-22625f85cf37", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "e517168d-c2ac-4ef4-893e-e7d809ccb4a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "84cd7591-19e5-4b45-be6d-22625f85cf37") },
		{ "8d7a1805-2634-4dc3-95e4-15207f4d8e1f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "9b188daf-13ee-470d-ab8d-2d9c75661e2a"}, { new NonTerminator(NonTerminatorType.Statement), "ab6c0946-5914-4e72-8c12-4b6e7c245045"}, { new NonTerminator(NonTerminatorType.Variable), "112924ad-56a4-4b25-b473-3719cf9f146d"}, { Terminator.IdentifierTerminator, "2ca36d82-352b-460d-9a9c-3820d154ae40"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72"}, { new Terminator(KeywordType.If), "73074719-3be9-46aa-80f3-1e8ee6a9b24b"}, { new Terminator(KeywordType.For), "a53fc2b7-1c76-4892-aefa-96321460277b"}, { new Terminator(KeywordType.Begin), "387138b7-6e8b-4b44-b497-4da7e03d863a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "8d7a1805-2634-4dc3-95e4-15207f4d8e1f") },
		{ "f37d6d6e-a5a0-44ab-acef-86be9430fd0c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "1642c114-8caf-40b7-b0d3-62291c623733"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "f37d6d6e-a5a0-44ab-acef-86be9430fd0c") },
		{ "590ddc2c-38fb-400e-a176-b5f385ff88da", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "cc940d53-a724-44a1-8e60-4f3c9ead595a"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "590ddc2c-38fb-400e-a176-b5f385ff88da") },
		{ "679ddcb5-a245-40ec-9fae-2b0973d2ffd5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "679ddcb5-a245-40ec-9fae-2b0973d2ffd5") },
		{ "e003a9f9-5fe2-4fa3-a274-aab8ca366a67", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "e003a9f9-5fe2-4fa3-a274-aab8ca366a67") },
		{ "fdb989a1-5f23-4da1-8cbb-76edef766de2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "fdb989a1-5f23-4da1-8cbb-76edef766de2") },
		{ "a10bbe8d-d2ae-4e67-9536-341e82afda65", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "05ed16d2-695e-4ce1-b3d4-d7c7b3d34537"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a10bbe8d-d2ae-4e67-9536-341e82afda65") },
		{ "2c41f32f-55b0-4ac7-8de9-3f33225a8bde", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "f032855a-1a43-4ead-9189-ff2ee24e3374"}, { new NonTerminator(NonTerminatorType.IdVarPart), "7482ba0b-b0d8-4f9d-af6d-c4e6eccee1a4"}, { new Terminator(DelimiterType.LeftSquareBracket), "ded67cf3-6641-431d-87f4-ddc5b1552a6d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "2c41f32f-55b0-4ac7-8de9-3f33225a8bde") },
		{ "6faa6c27-ef28-475e-bc81-7df55e5b749e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e3ffdcd2-6173-4d7c-beff-706e8e5d492c"}, { Terminator.NumberTerminator, "e003a9f9-5fe2-4fa3-a274-aab8ca366a67"}, { new NonTerminator(NonTerminatorType.Variable), "fdb989a1-5f23-4da1-8cbb-76edef766de2"}, { new Terminator(DelimiterType.LeftParenthesis), "a10bbe8d-d2ae-4e67-9536-341e82afda65"}, { Terminator.IdentifierTerminator, "2c41f32f-55b0-4ac7-8de9-3f33225a8bde"}, { new Terminator(KeywordType.Not), "6faa6c27-ef28-475e-bc81-7df55e5b749e"}, { new Terminator(OperatorType.Minus), "3c6d2331-578b-4df7-97af-139b9b6881b9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6faa6c27-ef28-475e-bc81-7df55e5b749e") },
		{ "3c6d2331-578b-4df7-97af-139b9b6881b9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "bc68dc56-2488-4a96-a9cf-e0e3a37a02c9"}, { Terminator.NumberTerminator, "e003a9f9-5fe2-4fa3-a274-aab8ca366a67"}, { new NonTerminator(NonTerminatorType.Variable), "fdb989a1-5f23-4da1-8cbb-76edef766de2"}, { new Terminator(DelimiterType.LeftParenthesis), "a10bbe8d-d2ae-4e67-9536-341e82afda65"}, { Terminator.IdentifierTerminator, "2c41f32f-55b0-4ac7-8de9-3f33225a8bde"}, { new Terminator(KeywordType.Not), "6faa6c27-ef28-475e-bc81-7df55e5b749e"}, { new Terminator(OperatorType.Minus), "3c6d2331-578b-4df7-97af-139b9b6881b9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3c6d2331-578b-4df7-97af-139b9b6881b9") },
		{ "979ef50b-7dc5-43b7-8f49-0cb3b9317a33", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "3ee1ab01-482f-42ab-bc07-045e877b8af2"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "979ef50b-7dc5-43b7-8f49-0cb3b9317a33") },
		{ "f9699208-5852-415f-8044-9569213d0673", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "f9699208-5852-415f-8044-9569213d0673") },
		{ "0dee96e1-f930-4027-9d8d-ceea7c2a49b7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "0dee96e1-f930-4027-9d8d-ceea7c2a49b7") },
		{ "fc0fb8d7-393d-4607-b11a-3b1f553b4390", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "2d255145-f87d-4a6e-9804-320f4f392a1f"}, { new NonTerminator(NonTerminatorType.Term), "b8849e86-115d-4c2a-ad54-a5bfbb2afdb9"}, { new NonTerminator(NonTerminatorType.Factor), "33c6d01d-f6bd-4bb3-9c1c-7357e3ffe1c6"}, { Terminator.NumberTerminator, "5e0d7b49-f9bc-4a95-8777-880cf2d47bcc"}, { new NonTerminator(NonTerminatorType.Variable), "88605b20-0e9f-458b-b47f-beb91b4c9a27"}, { new Terminator(DelimiterType.LeftParenthesis), "304939f4-4975-4778-88e7-ab611a2edc25"}, { Terminator.IdentifierTerminator, "3a89f862-6923-41cd-9727-46a014442f8b"}, { new Terminator(KeywordType.Not), "62fe6449-e173-475e-92b9-3d89f4e1e709"}, { new Terminator(OperatorType.Minus), "a5495176-f135-4105-bb6a-f12b7fa37a70"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fc0fb8d7-393d-4607-b11a-3b1f553b4390") },
		{ "4030816f-3e3a-44a3-85cb-9775d5218d41", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "0aa95f0b-982f-41a5-b1d7-e75d9b36b186"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4030816f-3e3a-44a3-85cb-9775d5218d41") },
		{ "a6c954e2-cd1d-4f2a-a59a-49f6cde2886c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "a641acfa-21de-4f81-824a-6eb7d6395210"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a6c954e2-cd1d-4f2a-a59a-49f6cde2886c") },
		{ "41696f89-d4f3-4f8a-b856-21e954879f7d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "9d05918f-bae3-471c-be10-f93afeebee57"},}, new Dictionary<Terminator, ReduceInformation>{ }, "41696f89-d4f3-4f8a-b856-21e954879f7d") },
		{ "e4c3489e-d8c3-45ac-ba55-7a0fca7975d7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "34429e12-94a1-4610-939a-f1f16c029048"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e4c3489e-d8c3-45ac-ba55-7a0fca7975d7") },
		{ "32ed1aea-aa0a-4129-8e95-f6a8bb02d932", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "32ed1aea-aa0a-4129-8e95-f6a8bb02d932") },
		{ "bc957a92-9eb8-47ef-84c6-83f63fb97172", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "38925d47-7ee9-466b-8fbc-5eebce08548b"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bc957a92-9eb8-47ef-84c6-83f63fb97172") },
		{ "5b6ebe5c-8f61-4cd2-bd66-641bbbc22fc2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "5b6ebe5c-8f61-4cd2-bd66-641bbbc22fc2") },
		{ "32d8e07e-48db-4bc7-98d3-ca91dc922594", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "32d8e07e-48db-4bc7-98d3-ca91dc922594") },
		{ "8611a6fa-68d1-4dfc-a264-d0407d3fa04f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "434a07ca-0f83-4ce7-9a59-ad0450b5b20e"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8611a6fa-68d1-4dfc-a264-d0407d3fa04f") },
		{ "2bd2926f-8578-481c-ac28-5e5c8d277acf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "e3a40806-f375-4e9f-953a-af6e8b17022e"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2bd2926f-8578-481c-ac28-5e5c8d277acf") },
		{ "8aacceed-0a42-4770-b4fc-7d6dd34a87c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.To), "f3719bc0-3151-441c-b9a8-40a7fffcf462"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8aacceed-0a42-4770-b4fc-7d6dd34a87c2") },
		{ "8b6a5494-2343-448c-992f-4570f3f4dc73", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "bf02df9b-ab7d-4b1a-9616-fd63fe69e271"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "10d86ef3-bdea-4446-a27b-08c5c58f5208"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "8b6a5494-2343-448c-992f-4570f3f4dc73") },
		{ "cdfef4a8-4523-4b63-aff2-e92c2bf95cb4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "11c433af-6913-4b14-8864-c238218e7f61"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "cdfef4a8-4523-4b63-aff2-e92c2bf95cb4") },
		{ "31efe073-cd8d-4d8b-8cab-33d1e7775d29", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "31efe073-cd8d-4d8b-8cab-33d1e7775d29") },
		{ "9047140a-81c6-48cb-b552-3e72ff88039f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "9047140a-81c6-48cb-b552-3e72ff88039f") },
		{ "b783bbe2-0d69-4647-b122-4dcbb03b97ac", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "b783bbe2-0d69-4647-b122-4dcbb03b97ac") },
		{ "a4e3b184-75b6-4f8b-8606-030803eb6125", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "3db15589-21a3-4fe6-89d8-43879d9908bb"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a4e3b184-75b6-4f8b-8606-030803eb6125") },
		{ "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "2235733d-ff74-4688-a3f0-5e7ddacf4b07"}, { new NonTerminator(NonTerminatorType.IdVarPart), "bbd5a4f5-2075-4756-9e3c-0862f0d243f2"}, { new Terminator(DelimiterType.LeftSquareBracket), "4c43980d-9a4d-47c2-8f87-83041f189bd6"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69") },
		{ "36de7783-58bd-4876-8056-1266ff3c75e9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "46e74071-ff66-46a9-b2e4-5e097aeac0f9"}, { Terminator.NumberTerminator, "9047140a-81c6-48cb-b552-3e72ff88039f"}, { new NonTerminator(NonTerminatorType.Variable), "b783bbe2-0d69-4647-b122-4dcbb03b97ac"}, { new Terminator(DelimiterType.LeftParenthesis), "a4e3b184-75b6-4f8b-8606-030803eb6125"}, { Terminator.IdentifierTerminator, "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69"}, { new Terminator(KeywordType.Not), "36de7783-58bd-4876-8056-1266ff3c75e9"}, { new Terminator(OperatorType.Minus), "62b09801-8689-4fff-9636-b6ac02ab3307"},}, new Dictionary<Terminator, ReduceInformation>{ }, "36de7783-58bd-4876-8056-1266ff3c75e9") },
		{ "62b09801-8689-4fff-9636-b6ac02ab3307", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "aa9fc6c8-e800-4187-83bd-055322b38cab"}, { Terminator.NumberTerminator, "9047140a-81c6-48cb-b552-3e72ff88039f"}, { new NonTerminator(NonTerminatorType.Variable), "b783bbe2-0d69-4647-b122-4dcbb03b97ac"}, { new Terminator(DelimiterType.LeftParenthesis), "a4e3b184-75b6-4f8b-8606-030803eb6125"}, { Terminator.IdentifierTerminator, "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69"}, { new Terminator(KeywordType.Not), "36de7783-58bd-4876-8056-1266ff3c75e9"}, { new Terminator(OperatorType.Minus), "62b09801-8689-4fff-9636-b6ac02ab3307"},}, new Dictionary<Terminator, ReduceInformation>{ }, "62b09801-8689-4fff-9636-b6ac02ab3307") },
		{ "e2df2d84-ec0c-481b-af32-4b05d46a1508", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramBody))}, }, "e2df2d84-ec0c-481b-af32-4b05d46a1508") },
		{ "0a15b54e-4f7f-450f-bc23-205961ec10cc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "8bba207b-f3cb-478e-9019-58bb2763e3f9"}, { new NonTerminator(NonTerminatorType.Statement), "ab6c0946-5914-4e72-8c12-4b6e7c245045"}, { new NonTerminator(NonTerminatorType.Variable), "112924ad-56a4-4b25-b473-3719cf9f146d"}, { Terminator.IdentifierTerminator, "2ca36d82-352b-460d-9a9c-3820d154ae40"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72"}, { new Terminator(KeywordType.If), "73074719-3be9-46aa-80f3-1e8ee6a9b24b"}, { new Terminator(KeywordType.For), "a53fc2b7-1c76-4892-aefa-96321460277b"}, { new Terminator(KeywordType.Begin), "387138b7-6e8b-4b44-b497-4da7e03d863a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "0a15b54e-4f7f-450f-bc23-205961ec10cc") },
		{ "7b1ed636-1796-452c-a6fb-e9c18431602f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "7b1ed636-1796-452c-a6fb-e9c18431602f") },
		{ "128773d3-b196-452b-be82-b6cc25d7d18e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Parameter), "7dfca8ca-d94d-4178-838e-7ab53a275ac6"}, { new NonTerminator(NonTerminatorType.VarParameter), "a32aefff-0ed1-4bae-a3fd-532141d91533"}, { new NonTerminator(NonTerminatorType.ValueParameter), "01389774-4d1f-4ad4-b947-38167c39ac54"}, { new Terminator(KeywordType.Var), "5a784796-e20c-43c1-baae-86fed3b82835"}, { new NonTerminator(NonTerminatorType.IdentifierList), "20774c5b-8cf2-402f-b07c-95fac09442ec"}, { Terminator.IdentifierTerminator, "9dc91f71-af68-404e-b670-a90589c075ea"},}, new Dictionary<Terminator, ReduceInformation>{ }, "128773d3-b196-452b-be82-b6cc25d7d18e") },
		{ "f01c147f-deea-49bb-a366-37349c1030a5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.VarParameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.VarParameter))}, }, "f01c147f-deea-49bb-a366-37349c1030a5") },
		{ "f8c3fc05-b87e-429f-8744-6b62a965e6f3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "cc6666c9-2666-47ee-a3e2-af3476d92578"}, { new Terminator(KeywordType.Integer), "9a2ef43a-24e6-41a8-b289-dda58f04c851"}, { new Terminator(KeywordType.Real), "ee0d421a-0240-4b63-b7aa-e0a97fac6e28"}, { new Terminator(KeywordType.Boolean), "5c546fbd-cd5b-4c37-bf15-d6e1ef1ab16a"}, { new Terminator(KeywordType.Character), "90affd93-8639-457c-8e5a-fc2adf658e2b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f8c3fc05-b87e-429f-8744-6b62a965e6f3") },
		{ "f7a87078-4f16-49b0-b230-830899dadd1e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.SubprogramHead))}, }, "f7a87078-4f16-49b0-b230-830899dadd1e") },
		{ "9bca897d-cab6-46c1-a5b8-04e8f2648e0b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "9bca897d-cab6-46c1-a5b8-04e8f2648e0b") },
		{ "25bcf90d-f787-4fd7-a28e-09954ce654b4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Of), "4aa39b34-8c99-4f1e-89e8-a67319a31b56"},}, new Dictionary<Terminator, ReduceInformation>{ }, "25bcf90d-f787-4fd7-a28e-09954ce654b4") },
		{ "08886912-7926-4ec7-ac86-622d47bf68c4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "c39093dc-a628-4d34-85a2-39327f8a55f0"},}, new Dictionary<Terminator, ReduceInformation>{ }, "08886912-7926-4ec7-ac86-622d47bf68c4") },
		{ "5cc8eda1-6e2c-43c7-acfa-115b42602420", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "36cc6b95-5378-4d7f-98c2-97356a7f65fc"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5cc8eda1-6e2c-43c7-acfa-115b42602420") },
		{ "80016048-6472-4366-a565-27de66e9c648", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "11928697-b309-44b8-9430-03885312012b"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "80016048-6472-4366-a565-27de66e9c648") },
		{ "7f4f76d2-aef6-4155-afa0-9234ed9f08cb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "6d62c2d9-622b-47c0-966b-376605d27cbb"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "7f4f76d2-aef6-4155-afa0-9234ed9f08cb") },
		{ "6a24b40f-d563-4fbb-b93c-93e65232d665", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "6a24b40f-d563-4fbb-b93c-93e65232d665") },
		{ "d3d7b60e-4bab-41a7-9df1-b34e21d63fdf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "d3d7b60e-4bab-41a7-9df1-b34e21d63fdf") },
		{ "09285f9d-9cb9-456e-b569-c95a72695c3b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "09285f9d-9cb9-456e-b569-c95a72695c3b") },
		{ "7b921bae-b232-40cb-9431-0a4935fdda35", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "039a3fbc-4e52-47b8-87a9-ed8d164552fe"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7b921bae-b232-40cb-9431-0a4935fdda35") },
		{ "615f7cdf-2a33-4f13-a3d0-c52709d8fb14", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "24295fb0-48d1-4ab1-b150-c69d2132f343"}, { new NonTerminator(NonTerminatorType.IdVarPart), "cf85ecab-1867-418a-bbef-0f476d04dd79"}, { new Terminator(DelimiterType.LeftSquareBracket), "007d325d-7d4f-4e29-84c6-084dd8782b63"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "615f7cdf-2a33-4f13-a3d0-c52709d8fb14") },
		{ "c2c51c07-8e89-40fe-8d4a-b3ba2f43fd16", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "76359bdf-03a2-4108-b327-d56a6130cfd0"}, { Terminator.NumberTerminator, "d3d7b60e-4bab-41a7-9df1-b34e21d63fdf"}, { new NonTerminator(NonTerminatorType.Variable), "09285f9d-9cb9-456e-b569-c95a72695c3b"}, { new Terminator(DelimiterType.LeftParenthesis), "7b921bae-b232-40cb-9431-0a4935fdda35"}, { Terminator.IdentifierTerminator, "615f7cdf-2a33-4f13-a3d0-c52709d8fb14"}, { new Terminator(KeywordType.Not), "c2c51c07-8e89-40fe-8d4a-b3ba2f43fd16"}, { new Terminator(OperatorType.Minus), "61c1af47-267f-4eec-82c4-8b857addf262"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c2c51c07-8e89-40fe-8d4a-b3ba2f43fd16") },
		{ "61c1af47-267f-4eec-82c4-8b857addf262", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "022111ef-f564-4055-9668-f16ccf5cf825"}, { Terminator.NumberTerminator, "d3d7b60e-4bab-41a7-9df1-b34e21d63fdf"}, { new NonTerminator(NonTerminatorType.Variable), "09285f9d-9cb9-456e-b569-c95a72695c3b"}, { new Terminator(DelimiterType.LeftParenthesis), "7b921bae-b232-40cb-9431-0a4935fdda35"}, { Terminator.IdentifierTerminator, "615f7cdf-2a33-4f13-a3d0-c52709d8fb14"}, { new Terminator(KeywordType.Not), "c2c51c07-8e89-40fe-8d4a-b3ba2f43fd16"}, { new Terminator(OperatorType.Minus), "61c1af47-267f-4eec-82c4-8b857addf262"},}, new Dictionary<Terminator, ReduceInformation>{ }, "61c1af47-267f-4eec-82c4-8b857addf262") },
		{ "16ecf6a3-5cd8-42f7-b4f3-0823e9686e6d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "51e2b277-c6f5-44be-87d5-d64c1466d57b"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "16ecf6a3-5cd8-42f7-b4f3-0823e9686e6d") },
		{ "77169fff-57ea-4eee-8ff1-9cfc311747e0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "77169fff-57ea-4eee-8ff1-9cfc311747e0") },
		{ "f014e20b-4084-40d1-8a1d-ffce04d50197", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "f014e20b-4084-40d1-8a1d-ffce04d50197") },
		{ "53f8abc4-8569-4f94-8714-730a9b6ed96e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "d5c534a8-fbdc-41e6-bc6e-910f2c2fce73"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "53f8abc4-8569-4f94-8714-730a9b6ed96e") },
		{ "ac6f4d9d-f19a-4fef-bc01-6bb0ad771565", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "8879daeb-1878-40d4-ad20-c73923683697"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ac6f4d9d-f19a-4fef-bc01-6bb0ad771565") },
		{ "2764259e-46a1-4042-b120-96622c169496", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "2764259e-46a1-4042-b120-96622c169496") },
		{ "368d4fe6-f7ec-4bbd-a1fd-8394de0a6994", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "2d6dbc2f-aeee-45a2-b8ea-fcdb246f30c1"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "368d4fe6-f7ec-4bbd-a1fd-8394de0a6994") },
		{ "2af15985-274c-494e-8006-04d1e56c434b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d63cc5e2-684c-4b4f-aee7-92fd26fc3432"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "2af15985-274c-494e-8006-04d1e56c434b") },
		{ "f6afc2a2-d7cf-45f9-b1e3-347690927214", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "f6afc2a2-d7cf-45f9-b1e3-347690927214") },
		{ "d92561e5-ab5f-46f9-bdf0-12691df87dc5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "d92561e5-ab5f-46f9-bdf0-12691df87dc5") },
		{ "a2d65047-b87e-423f-b1cf-59c048ad7daa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "a2d65047-b87e-423f-b1cf-59c048ad7daa") },
		{ "3c1034e3-0d98-4c46-9df4-5376b518de2c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "8cab3ddd-4203-4b39-8c83-a4e2b5091c17"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3c1034e3-0d98-4c46-9df4-5376b518de2c") },
		{ "85889ca5-6e30-4bcc-8282-c72224ec8608", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "fb2388d0-3494-49d1-abb7-388c6cbd1663"}, { new NonTerminator(NonTerminatorType.IdVarPart), "d5e54951-3f9e-4ae9-a357-5d0d7a933fbb"}, { new Terminator(DelimiterType.LeftSquareBracket), "9d50e326-11f6-4125-9791-ba15a8b836cb"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "85889ca5-6e30-4bcc-8282-c72224ec8608") },
		{ "c94499cc-f088-48d3-93e8-0da61332b846", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "154915c2-4bb8-4e1d-aca5-4fb6048f4adc"}, { Terminator.NumberTerminator, "d92561e5-ab5f-46f9-bdf0-12691df87dc5"}, { new NonTerminator(NonTerminatorType.Variable), "a2d65047-b87e-423f-b1cf-59c048ad7daa"}, { new Terminator(DelimiterType.LeftParenthesis), "3c1034e3-0d98-4c46-9df4-5376b518de2c"}, { Terminator.IdentifierTerminator, "85889ca5-6e30-4bcc-8282-c72224ec8608"}, { new Terminator(KeywordType.Not), "c94499cc-f088-48d3-93e8-0da61332b846"}, { new Terminator(OperatorType.Minus), "7e0f0929-19f3-42a8-b568-878a7b81617e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c94499cc-f088-48d3-93e8-0da61332b846") },
		{ "7e0f0929-19f3-42a8-b568-878a7b81617e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "2391f6d1-da49-4141-9e23-0d11dc65cbdc"}, { Terminator.NumberTerminator, "d92561e5-ab5f-46f9-bdf0-12691df87dc5"}, { new NonTerminator(NonTerminatorType.Variable), "a2d65047-b87e-423f-b1cf-59c048ad7daa"}, { new Terminator(DelimiterType.LeftParenthesis), "3c1034e3-0d98-4c46-9df4-5376b518de2c"}, { Terminator.IdentifierTerminator, "85889ca5-6e30-4bcc-8282-c72224ec8608"}, { new Terminator(KeywordType.Not), "c94499cc-f088-48d3-93e8-0da61332b846"}, { new Terminator(OperatorType.Minus), "7e0f0929-19f3-42a8-b568-878a7b81617e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7e0f0929-19f3-42a8-b568-878a7b81617e") },
		{ "7a5cb99c-2567-4f4a-9bd2-efc049c1eaf7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "de1cc3ab-1a1e-4a3e-99ee-ee6161b1eff2"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "7a5cb99c-2567-4f4a-9bd2-efc049c1eaf7") },
		{ "e9d6db93-4578-466f-8b5c-fe98530c8a05", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "e9d6db93-4578-466f-8b5c-fe98530c8a05") },
		{ "e8700800-7eee-4eba-a1a7-2a7d471187bc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "e8700800-7eee-4eba-a1a7-2a7d471187bc") },
		{ "cd499a9c-5961-4cc1-b4c8-45b82d390499", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "009f921f-888c-4563-8a6d-3aa40ed9ccc0"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cd499a9c-5961-4cc1-b4c8-45b82d390499") },
		{ "ce59817f-d8ad-4a9b-b0a7-a37e18618e62", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "06821323-14ad-47cf-8ccb-0600fbee7306"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ce59817f-d8ad-4a9b-b0a7-a37e18618e62") },
		{ "6d14ee42-1f5e-40c1-914e-607b6c5f1e24", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "6d14ee42-1f5e-40c1-914e-607b6c5f1e24") },
		{ "4158fa98-635d-4a63-88ec-7f3037df1aa9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "9d99514e-f920-460d-b3e9-9458109fbc1b"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "4158fa98-635d-4a63-88ec-7f3037df1aa9") },
		{ "d39336cb-35d8-44d2-b35b-548a3ac7a15f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "fcdcf686-3d55-46d3-90b6-471760cfec40"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "d39336cb-35d8-44d2-b35b-548a3ac7a15f") },
		{ "55259b52-bdfa-4c54-80f0-8882489977a7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "55259b52-bdfa-4c54-80f0-8882489977a7") },
		{ "17272e2b-9263-42c1-bcfa-59955b608bdd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "17272e2b-9263-42c1-bcfa-59955b608bdd") },
		{ "ac7e5cb8-938b-47eb-aac5-d550639bec19", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "ac7e5cb8-938b-47eb-aac5-d550639bec19") },
		{ "9c2fa58e-138d-4b14-9b14-9578f2fb0c6a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "1197768a-1614-43d6-a770-b0461137d52b"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9c2fa58e-138d-4b14-9b14-9578f2fb0c6a") },
		{ "236624af-bfe0-4a02-b536-b5f86c53bd35", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "e58a7df9-7c08-48ca-a494-14b819745bdf"}, { new NonTerminator(NonTerminatorType.IdVarPart), "652fd2c2-4afa-49ea-936a-4fa8a19132f3"}, { new Terminator(DelimiterType.LeftSquareBracket), "e7291936-18c0-4d72-91d3-349e63bca94d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "236624af-bfe0-4a02-b536-b5f86c53bd35") },
		{ "7c9dfa64-f1dd-46aa-9839-3d31f42f0192", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3b3e11a7-9819-4115-a921-1a06989bb22d"}, { Terminator.NumberTerminator, "17272e2b-9263-42c1-bcfa-59955b608bdd"}, { new NonTerminator(NonTerminatorType.Variable), "ac7e5cb8-938b-47eb-aac5-d550639bec19"}, { new Terminator(DelimiterType.LeftParenthesis), "9c2fa58e-138d-4b14-9b14-9578f2fb0c6a"}, { Terminator.IdentifierTerminator, "236624af-bfe0-4a02-b536-b5f86c53bd35"}, { new Terminator(KeywordType.Not), "7c9dfa64-f1dd-46aa-9839-3d31f42f0192"}, { new Terminator(OperatorType.Minus), "404a3540-776d-4af0-a69b-e62dba9820d2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7c9dfa64-f1dd-46aa-9839-3d31f42f0192") },
		{ "404a3540-776d-4af0-a69b-e62dba9820d2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3850931e-58cb-4a51-81d3-7532bb7f9dbc"}, { Terminator.NumberTerminator, "17272e2b-9263-42c1-bcfa-59955b608bdd"}, { new NonTerminator(NonTerminatorType.Variable), "ac7e5cb8-938b-47eb-aac5-d550639bec19"}, { new Terminator(DelimiterType.LeftParenthesis), "9c2fa58e-138d-4b14-9b14-9578f2fb0c6a"}, { Terminator.IdentifierTerminator, "236624af-bfe0-4a02-b536-b5f86c53bd35"}, { new Terminator(KeywordType.Not), "7c9dfa64-f1dd-46aa-9839-3d31f42f0192"}, { new Terminator(OperatorType.Minus), "404a3540-776d-4af0-a69b-e62dba9820d2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "404a3540-776d-4af0-a69b-e62dba9820d2") },
		{ "ee316822-0e3c-473c-a087-0591592be4c3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "90863c9b-ac16-49a4-93f3-65cb3507c4c1"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "ee316822-0e3c-473c-a087-0591592be4c3") },
		{ "53e3a8ab-2719-4f80-b1dc-fb8c168e87fb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "53e3a8ab-2719-4f80-b1dc-fb8c168e87fb") },
		{ "727a6a40-ca19-4f5e-b344-3749c08fd86e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "727a6a40-ca19-4f5e-b344-3749c08fd86e") },
		{ "a2c3f894-e8ca-490b-bcf0-0ba2bec3ba02", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a3003791-a94a-4f0f-a581-2a9d0db5a207"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a2c3f894-e8ca-490b-bcf0-0ba2bec3ba02") },
		{ "a57f78cd-0cfb-49cc-b6f9-7c290c2db7ed", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "4521d328-a662-4c8f-8694-e379a042733d"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a57f78cd-0cfb-49cc-b6f9-7c290c2db7ed") },
		{ "ee93c3b1-f118-46e9-a12c-6e4fafda9a32", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, }, "ee93c3b1-f118-46e9-a12c-6e4fafda9a32") },
		{ "bbde4b09-6361-4cd1-b448-0c3193f11586", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "37a1ee73-c567-409e-bdee-b33d0aae9a57"}, { new NonTerminator(NonTerminatorType.Variable), "112924ad-56a4-4b25-b473-3719cf9f146d"}, { Terminator.IdentifierTerminator, "2ca36d82-352b-460d-9a9c-3820d154ae40"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72"}, { new Terminator(KeywordType.If), "73074719-3be9-46aa-80f3-1e8ee6a9b24b"}, { new Terminator(KeywordType.For), "a53fc2b7-1c76-4892-aefa-96321460277b"}, { new Terminator(KeywordType.Begin), "387138b7-6e8b-4b44-b497-4da7e03d863a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "bbde4b09-6361-4cd1-b448-0c3193f11586") },
		{ "c4a65452-2c63-4ae0-9f17-d748e6ce410b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "1e39e9b8-4548-4b80-93ee-79ff8d0c1a9c"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8902871b-7367-4542-a832-006b3e011090"}, { new NonTerminator(NonTerminatorType.Term), "6bf5c1bc-7a00-444d-bdac-c86414b9ea3e"}, { new NonTerminator(NonTerminatorType.Factor), "79e3e401-f279-4a6a-9967-663e8cbb55d3"}, { Terminator.NumberTerminator, "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7"}, { new NonTerminator(NonTerminatorType.Variable), "04c396bf-b0e6-400f-9df0-4071948f4978"}, { new Terminator(DelimiterType.LeftParenthesis), "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2"}, { Terminator.IdentifierTerminator, "0e7ea382-709e-41b3-b056-d4c1a3e6b051"}, { new Terminator(KeywordType.Not), "1a926f7d-7785-49ff-811f-c8ff008a4f77"}, { new Terminator(OperatorType.Minus), "ac70368d-2b3f-45d1-98e2-bbd70f25d707"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c4a65452-2c63-4ae0-9f17-d748e6ce410b") },
		{ "f5aafea0-87c3-4a9e-bd84-e79e65671bc1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "f3e8d365-be88-42fd-bb71-b24a1efc6123"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8902871b-7367-4542-a832-006b3e011090"}, { new NonTerminator(NonTerminatorType.Term), "6bf5c1bc-7a00-444d-bdac-c86414b9ea3e"}, { new NonTerminator(NonTerminatorType.Factor), "79e3e401-f279-4a6a-9967-663e8cbb55d3"}, { Terminator.NumberTerminator, "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7"}, { new NonTerminator(NonTerminatorType.Variable), "04c396bf-b0e6-400f-9df0-4071948f4978"}, { new Terminator(DelimiterType.LeftParenthesis), "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2"}, { Terminator.IdentifierTerminator, "0e7ea382-709e-41b3-b056-d4c1a3e6b051"}, { new Terminator(KeywordType.Not), "1a926f7d-7785-49ff-811f-c8ff008a4f77"}, { new Terminator(OperatorType.Minus), "ac70368d-2b3f-45d1-98e2-bbd70f25d707"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f5aafea0-87c3-4a9e-bd84-e79e65671bc1") },
		{ "4f0710b6-1b96-4b80-a239-e70be7c44b4e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "e7cb8123-3b86-4350-bcc1-cde00bf0ea2d"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4f0710b6-1b96-4b80-a239-e70be7c44b4e") },
		{ "df85ff83-ff09-44ca-9c1f-699bf73f9f32", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Then), "cf3f049d-e11b-4bce-b0f0-70e3187c0e1e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "df85ff83-ff09-44ca-9c1f-699bf73f9f32") },
		{ "e517168d-c2ac-4ef4-893e-e7d809ccb4a7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "e91935d2-8492-40d5-81a2-f57e7771db96"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e517168d-c2ac-4ef4-893e-e7d809ccb4a7") },
		{ "9b188daf-13ee-470d-ab8d-2d9c75661e2a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "13a46cdd-dc4a-4b78-b939-9ef99ce4039a"}, { new Terminator(DelimiterType.Semicolon), "5f77fc2d-16b7-4de2-aa95-a5b4bf60ead7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9b188daf-13ee-470d-ab8d-2d9c75661e2a") },
		{ "1642c114-8caf-40b7-b0d3-62291c623733", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "225811d4-700a-4aa0-a97e-25c9eb154100"}, { new NonTerminator(NonTerminatorType.Factor), "679ddcb5-a245-40ec-9fae-2b0973d2ffd5"}, { Terminator.NumberTerminator, "e003a9f9-5fe2-4fa3-a274-aab8ca366a67"}, { new NonTerminator(NonTerminatorType.Variable), "fdb989a1-5f23-4da1-8cbb-76edef766de2"}, { new Terminator(DelimiterType.LeftParenthesis), "a10bbe8d-d2ae-4e67-9536-341e82afda65"}, { Terminator.IdentifierTerminator, "2c41f32f-55b0-4ac7-8de9-3f33225a8bde"}, { new Terminator(KeywordType.Not), "6faa6c27-ef28-475e-bc81-7df55e5b749e"}, { new Terminator(OperatorType.Minus), "3c6d2331-578b-4df7-97af-139b9b6881b9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1642c114-8caf-40b7-b0d3-62291c623733") },
		{ "cc940d53-a724-44a1-8e60-4f3c9ead595a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e05512fd-aa08-4f49-8d68-1f5d7c4b56e2"}, { Terminator.NumberTerminator, "e003a9f9-5fe2-4fa3-a274-aab8ca366a67"}, { new NonTerminator(NonTerminatorType.Variable), "fdb989a1-5f23-4da1-8cbb-76edef766de2"}, { new Terminator(DelimiterType.LeftParenthesis), "a10bbe8d-d2ae-4e67-9536-341e82afda65"}, { Terminator.IdentifierTerminator, "2c41f32f-55b0-4ac7-8de9-3f33225a8bde"}, { new Terminator(KeywordType.Not), "6faa6c27-ef28-475e-bc81-7df55e5b749e"}, { new Terminator(OperatorType.Minus), "3c6d2331-578b-4df7-97af-139b9b6881b9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cc940d53-a724-44a1-8e60-4f3c9ead595a") },
		{ "05ed16d2-695e-4ce1-b3d4-d7c7b3d34537", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "8c00ad64-42a6-42b4-86fa-19329ebec708"},}, new Dictionary<Terminator, ReduceInformation>{ }, "05ed16d2-695e-4ce1-b3d4-d7c7b3d34537") },
		{ "f032855a-1a43-4ead-9189-ff2ee24e3374", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "5448f54e-4968-4d64-9a0a-3ad9102f27c2"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f032855a-1a43-4ead-9189-ff2ee24e3374") },
		{ "7482ba0b-b0d8-4f9d-af6d-c4e6eccee1a4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "7482ba0b-b0d8-4f9d-af6d-c4e6eccee1a4") },
		{ "ded67cf3-6641-431d-87f4-ddc5b1552a6d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "b8f8e23a-4371-486c-82ea-3e2f213ffa97"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ded67cf3-6641-431d-87f4-ddc5b1552a6d") },
		{ "e3ffdcd2-6173-4d7c-beff-706e8e5d492c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "e3ffdcd2-6173-4d7c-beff-706e8e5d492c") },
		{ "bc68dc56-2488-4a96-a9cf-e0e3a37a02c9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "bc68dc56-2488-4a96-a9cf-e0e3a37a02c9") },
		{ "2d255145-f87d-4a6e-9804-320f4f392a1f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "51afb469-2974-4a34-b1f0-a3a346ef2834"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "2d255145-f87d-4a6e-9804-320f4f392a1f") },
		{ "b8849e86-115d-4c2a-ad54-a5bfbb2afdb9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "96695dea-b9fb-4972-ba90-6f5ba1cfaf16"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "b8849e86-115d-4c2a-ad54-a5bfbb2afdb9") },
		{ "33c6d01d-f6bd-4bb3-9c1c-7357e3ffe1c6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "33c6d01d-f6bd-4bb3-9c1c-7357e3ffe1c6") },
		{ "5e0d7b49-f9bc-4a95-8777-880cf2d47bcc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "5e0d7b49-f9bc-4a95-8777-880cf2d47bcc") },
		{ "88605b20-0e9f-458b-b47f-beb91b4c9a27", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "88605b20-0e9f-458b-b47f-beb91b4c9a27") },
		{ "304939f4-4975-4778-88e7-ab611a2edc25", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "1e5a9194-48ad-401b-aa1d-3c7e412423e2"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "304939f4-4975-4778-88e7-ab611a2edc25") },
		{ "3a89f862-6923-41cd-9727-46a014442f8b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "b57a24ea-2c05-44aa-b7d1-c9d3afa32461"}, { new NonTerminator(NonTerminatorType.IdVarPart), "1097b4bf-51d9-4fd7-bc40-fdc04782bc48"}, { new Terminator(DelimiterType.LeftSquareBracket), "69868a82-92fa-42ac-937b-f252b57c547a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "3a89f862-6923-41cd-9727-46a014442f8b") },
		{ "62fe6449-e173-475e-92b9-3d89f4e1e709", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "32b5171a-2a01-4937-a4cf-fc5a186ec0e8"}, { Terminator.NumberTerminator, "5e0d7b49-f9bc-4a95-8777-880cf2d47bcc"}, { new NonTerminator(NonTerminatorType.Variable), "88605b20-0e9f-458b-b47f-beb91b4c9a27"}, { new Terminator(DelimiterType.LeftParenthesis), "304939f4-4975-4778-88e7-ab611a2edc25"}, { Terminator.IdentifierTerminator, "3a89f862-6923-41cd-9727-46a014442f8b"}, { new Terminator(KeywordType.Not), "62fe6449-e173-475e-92b9-3d89f4e1e709"}, { new Terminator(OperatorType.Minus), "a5495176-f135-4105-bb6a-f12b7fa37a70"},}, new Dictionary<Terminator, ReduceInformation>{ }, "62fe6449-e173-475e-92b9-3d89f4e1e709") },
		{ "a5495176-f135-4105-bb6a-f12b7fa37a70", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "ffd682a7-4496-4cb2-a789-e065e964f0d3"}, { Terminator.NumberTerminator, "5e0d7b49-f9bc-4a95-8777-880cf2d47bcc"}, { new NonTerminator(NonTerminatorType.Variable), "88605b20-0e9f-458b-b47f-beb91b4c9a27"}, { new Terminator(DelimiterType.LeftParenthesis), "304939f4-4975-4778-88e7-ab611a2edc25"}, { Terminator.IdentifierTerminator, "3a89f862-6923-41cd-9727-46a014442f8b"}, { new Terminator(KeywordType.Not), "62fe6449-e173-475e-92b9-3d89f4e1e709"}, { new Terminator(OperatorType.Minus), "a5495176-f135-4105-bb6a-f12b7fa37a70"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a5495176-f135-4105-bb6a-f12b7fa37a70") },
		{ "0aa95f0b-982f-41a5-b1d7-e75d9b36b186", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "a6c954e2-cd1d-4f2a-a59a-49f6cde2886c"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "0aa95f0b-982f-41a5-b1d7-e75d9b36b186") },
		{ "a641acfa-21de-4f81-824a-6eb7d6395210", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "a641acfa-21de-4f81-824a-6eb7d6395210") },
		{ "9d05918f-bae3-471c-be10-f93afeebee57", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "9d05918f-bae3-471c-be10-f93afeebee57") },
		{ "34429e12-94a1-4610-939a-f1f16c029048", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "32385a4e-647c-46e8-a951-3f9cb44b149f"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "34429e12-94a1-4610-939a-f1f16c029048") },
		{ "38925d47-7ee9-466b-8fbc-5eebce08548b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "941c2727-971a-494c-84fe-a3e1f2b740bf"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "38925d47-7ee9-466b-8fbc-5eebce08548b") },
		{ "434a07ca-0f83-4ce7-9a59-ad0450b5b20e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "434a07ca-0f83-4ce7-9a59-ad0450b5b20e") },
		{ "e3a40806-f375-4e9f-953a-af6e8b17022e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "e3a40806-f375-4e9f-953a-af6e8b17022e") },
		{ "f3719bc0-3151-441c-b9a8-40a7fffcf462", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "7f5e0ad7-4333-43ef-a361-fbf4d385b072"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8170e558-7639-478c-b3ad-d788f869d31c"}, { new NonTerminator(NonTerminatorType.Term), "58feff7d-cb2f-46c5-b8f4-8671620139cf"}, { new NonTerminator(NonTerminatorType.Factor), "5019c8be-58b7-43d8-bea8-0be597093c13"}, { Terminator.NumberTerminator, "5f5dfe62-b936-4a95-bda3-215e63344425"}, { new NonTerminator(NonTerminatorType.Variable), "ef9d65a5-871b-4e27-b850-024c266004e2"}, { new Terminator(DelimiterType.LeftParenthesis), "8b3d0c2a-df98-4667-98cf-6de6d74d4910"}, { Terminator.IdentifierTerminator, "24b5a051-ab9e-4a1e-bd34-82fe7c82cede"}, { new Terminator(KeywordType.Not), "bc126c07-4e05-405b-8214-47da44b79eb3"}, { new Terminator(OperatorType.Minus), "bad4d95a-9b87-4d9d-89b3-2f81d055bac4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f3719bc0-3151-441c-b9a8-40a7fffcf462") },
		{ "bf02df9b-ab7d-4b1a-9616-fd63fe69e271", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "cd4b0d85-9096-4087-a054-2ca1a4a09b1f"}, { new NonTerminator(NonTerminatorType.Term), "52319dd3-e4cb-42a1-8b15-3946994631b3"}, { new NonTerminator(NonTerminatorType.Factor), "7dc12ae0-4efc-42ff-9512-0a99162124c0"}, { Terminator.NumberTerminator, "4ef11303-cb21-4535-85fa-cb490faac422"}, { new NonTerminator(NonTerminatorType.Variable), "16358e64-c0a2-43c1-9ab7-e1d9327495e0"}, { new Terminator(DelimiterType.LeftParenthesis), "d65c4055-3e12-492d-9a71-870e92cc47b1"}, { Terminator.IdentifierTerminator, "b3001572-4edd-4505-a8a0-ece02b06990e"}, { new Terminator(KeywordType.Not), "84e9d49f-1787-4946-8fab-c3d912cfd7d5"}, { new Terminator(OperatorType.Minus), "2fc476a5-3b8a-49f9-8c19-d1ca68bfb821"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bf02df9b-ab7d-4b1a-9616-fd63fe69e271") },
		{ "10d86ef3-bdea-4446-a27b-08c5c58f5208", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "8e30d65d-8ffd-49ef-8231-da25634b6748"}, { new NonTerminator(NonTerminatorType.Factor), "31efe073-cd8d-4d8b-8cab-33d1e7775d29"}, { Terminator.NumberTerminator, "9047140a-81c6-48cb-b552-3e72ff88039f"}, { new NonTerminator(NonTerminatorType.Variable), "b783bbe2-0d69-4647-b122-4dcbb03b97ac"}, { new Terminator(DelimiterType.LeftParenthesis), "a4e3b184-75b6-4f8b-8606-030803eb6125"}, { Terminator.IdentifierTerminator, "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69"}, { new Terminator(KeywordType.Not), "36de7783-58bd-4876-8056-1266ff3c75e9"}, { new Terminator(OperatorType.Minus), "62b09801-8689-4fff-9636-b6ac02ab3307"},}, new Dictionary<Terminator, ReduceInformation>{ }, "10d86ef3-bdea-4446-a27b-08c5c58f5208") },
		{ "11c433af-6913-4b14-8864-c238218e7f61", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "137702b9-425d-4547-8c6e-9f59730f6091"}, { Terminator.NumberTerminator, "9047140a-81c6-48cb-b552-3e72ff88039f"}, { new NonTerminator(NonTerminatorType.Variable), "b783bbe2-0d69-4647-b122-4dcbb03b97ac"}, { new Terminator(DelimiterType.LeftParenthesis), "a4e3b184-75b6-4f8b-8606-030803eb6125"}, { Terminator.IdentifierTerminator, "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69"}, { new Terminator(KeywordType.Not), "36de7783-58bd-4876-8056-1266ff3c75e9"}, { new Terminator(OperatorType.Minus), "62b09801-8689-4fff-9636-b6ac02ab3307"},}, new Dictionary<Terminator, ReduceInformation>{ }, "11c433af-6913-4b14-8864-c238218e7f61") },
		{ "3db15589-21a3-4fe6-89d8-43879d9908bb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "2348e9b4-af41-46cf-87be-af281dc23e2a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3db15589-21a3-4fe6-89d8-43879d9908bb") },
		{ "2235733d-ff74-4688-a3f0-5e7ddacf4b07", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "ab33677c-e8b4-4058-b769-d04e0880af7a"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2235733d-ff74-4688-a3f0-5e7ddacf4b07") },
		{ "bbd5a4f5-2075-4756-9e3c-0862f0d243f2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "bbd5a4f5-2075-4756-9e3c-0862f0d243f2") },
		{ "4c43980d-9a4d-47c2-8f87-83041f189bd6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "cfa9c33f-64c6-42b1-b14a-2a59a8aa26fe"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4c43980d-9a4d-47c2-8f87-83041f189bd6") },
		{ "46e74071-ff66-46a9-b2e4-5e097aeac0f9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "46e74071-ff66-46a9-b2e4-5e097aeac0f9") },
		{ "aa9fc6c8-e800-4187-83bd-055322b38cab", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "aa9fc6c8-e800-4187-83bd-055322b38cab") },
		{ "8bba207b-f3cb-478e-9019-58bb2763e3f9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "7ef948bb-4168-4668-b0c7-2657a3495568"}, { new Terminator(DelimiterType.Semicolon), "5f77fc2d-16b7-4de2-aa95-a5b4bf60ead7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8bba207b-f3cb-478e-9019-58bb2763e3f9") },
		{ "7dfca8ca-d94d-4178-838e-7ab53a275ac6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ParameterList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ParameterList))}, }, "7dfca8ca-d94d-4178-838e-7ab53a275ac6") },
		{ "cc6666c9-2666-47ee-a3e2-af3476d92578", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ValueParameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ValueParameter))}, }, "cc6666c9-2666-47ee-a3e2-af3476d92578") },
		{ "9a2ef43a-24e6-41a8-b289-dda58f04c851", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "9a2ef43a-24e6-41a8-b289-dda58f04c851") },
		{ "ee0d421a-0240-4b63-b7aa-e0a97fac6e28", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "ee0d421a-0240-4b63-b7aa-e0a97fac6e28") },
		{ "5c546fbd-cd5b-4c37-bf15-d6e1ef1ab16a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "5c546fbd-cd5b-4c37-bf15-d6e1ef1ab16a") },
		{ "90affd93-8639-457c-8e5a-fc2adf658e2b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "90affd93-8639-457c-8e5a-fc2adf658e2b") },
		{ "4aa39b34-8c99-4f1e-89e8-a67319a31b56", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "0f36db83-65d1-4f20-a7ae-9d7ece62b66c"}, { new Terminator(KeywordType.Integer), "7a45914c-6e41-40b0-af8d-3aee3f58b52e"}, { new Terminator(KeywordType.Real), "0c324ffd-6717-4e32-84e1-b20373faf37a"}, { new Terminator(KeywordType.Boolean), "2038cb87-ab6e-4cdf-875f-99acab7590d6"}, { new Terminator(KeywordType.Character), "dcf92153-cf0c-4c29-858a-e1ae80990401"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4aa39b34-8c99-4f1e-89e8-a67319a31b56") },
		{ "c39093dc-a628-4d34-85a2-39327f8a55f0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.DoubleDots), "7b6d3a54-b68b-4a49-a034-4d20cefeadf4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c39093dc-a628-4d34-85a2-39327f8a55f0") },
		{ "36cc6b95-5378-4d7f-98c2-97356a7f65fc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Period))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Period))}, }, "36cc6b95-5378-4d7f-98c2-97356a7f65fc") },
		{ "11928697-b309-44b8-9430-03885312012b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "a72b4a5d-fde1-4bf5-ba12-51afdef59ab1"}, { new NonTerminator(NonTerminatorType.Factor), "6a24b40f-d563-4fbb-b93c-93e65232d665"}, { Terminator.NumberTerminator, "d3d7b60e-4bab-41a7-9df1-b34e21d63fdf"}, { new NonTerminator(NonTerminatorType.Variable), "09285f9d-9cb9-456e-b569-c95a72695c3b"}, { new Terminator(DelimiterType.LeftParenthesis), "7b921bae-b232-40cb-9431-0a4935fdda35"}, { Terminator.IdentifierTerminator, "615f7cdf-2a33-4f13-a3d0-c52709d8fb14"}, { new Terminator(KeywordType.Not), "c2c51c07-8e89-40fe-8d4a-b3ba2f43fd16"}, { new Terminator(OperatorType.Minus), "61c1af47-267f-4eec-82c4-8b857addf262"},}, new Dictionary<Terminator, ReduceInformation>{ }, "11928697-b309-44b8-9430-03885312012b") },
		{ "6d62c2d9-622b-47c0-966b-376605d27cbb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "2e6e51a4-c9a2-4e5b-b40f-e006bb9cb9ff"}, { Terminator.NumberTerminator, "d3d7b60e-4bab-41a7-9df1-b34e21d63fdf"}, { new NonTerminator(NonTerminatorType.Variable), "09285f9d-9cb9-456e-b569-c95a72695c3b"}, { new Terminator(DelimiterType.LeftParenthesis), "7b921bae-b232-40cb-9431-0a4935fdda35"}, { Terminator.IdentifierTerminator, "615f7cdf-2a33-4f13-a3d0-c52709d8fb14"}, { new Terminator(KeywordType.Not), "c2c51c07-8e89-40fe-8d4a-b3ba2f43fd16"}, { new Terminator(OperatorType.Minus), "61c1af47-267f-4eec-82c4-8b857addf262"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6d62c2d9-622b-47c0-966b-376605d27cbb") },
		{ "039a3fbc-4e52-47b8-87a9-ed8d164552fe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "e9af9eaf-ff2c-4af6-b253-16ece4ccfa54"},}, new Dictionary<Terminator, ReduceInformation>{ }, "039a3fbc-4e52-47b8-87a9-ed8d164552fe") },
		{ "24295fb0-48d1-4ab1-b150-c69d2132f343", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "32a59706-cf5b-48b6-b352-4a6e9e31da8a"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "24295fb0-48d1-4ab1-b150-c69d2132f343") },
		{ "cf85ecab-1867-418a-bbef-0f476d04dd79", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "cf85ecab-1867-418a-bbef-0f476d04dd79") },
		{ "007d325d-7d4f-4e29-84c6-084dd8782b63", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "65125b6e-f75f-4b8e-96f1-a50a34ba35fe"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "007d325d-7d4f-4e29-84c6-084dd8782b63") },
		{ "76359bdf-03a2-4108-b327-d56a6130cfd0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "76359bdf-03a2-4108-b327-d56a6130cfd0") },
		{ "022111ef-f564-4055-9668-f16ccf5cf825", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "022111ef-f564-4055-9668-f16ccf5cf825") },
		{ "d5c534a8-fbdc-41e6-bc6e-910f2c2fce73", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "d5c534a8-fbdc-41e6-bc6e-910f2c2fce73") },
		{ "8879daeb-1878-40d4-ad20-c73923683697", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "8879daeb-1878-40d4-ad20-c73923683697") },
		{ "2d6dbc2f-aeee-45a2-b8ea-fcdb246f30c1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "47fad12d-892b-4216-9ffb-8792b4d7b4ee"}, { new NonTerminator(NonTerminatorType.Factor), "f6afc2a2-d7cf-45f9-b1e3-347690927214"}, { Terminator.NumberTerminator, "d92561e5-ab5f-46f9-bdf0-12691df87dc5"}, { new NonTerminator(NonTerminatorType.Variable), "a2d65047-b87e-423f-b1cf-59c048ad7daa"}, { new Terminator(DelimiterType.LeftParenthesis), "3c1034e3-0d98-4c46-9df4-5376b518de2c"}, { Terminator.IdentifierTerminator, "85889ca5-6e30-4bcc-8282-c72224ec8608"}, { new Terminator(KeywordType.Not), "c94499cc-f088-48d3-93e8-0da61332b846"}, { new Terminator(OperatorType.Minus), "7e0f0929-19f3-42a8-b568-878a7b81617e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2d6dbc2f-aeee-45a2-b8ea-fcdb246f30c1") },
		{ "d63cc5e2-684c-4b4f-aee7-92fd26fc3432", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "9833770b-ce8e-4df0-b89f-15c5c018c032"}, { Terminator.NumberTerminator, "d92561e5-ab5f-46f9-bdf0-12691df87dc5"}, { new NonTerminator(NonTerminatorType.Variable), "a2d65047-b87e-423f-b1cf-59c048ad7daa"}, { new Terminator(DelimiterType.LeftParenthesis), "3c1034e3-0d98-4c46-9df4-5376b518de2c"}, { Terminator.IdentifierTerminator, "85889ca5-6e30-4bcc-8282-c72224ec8608"}, { new Terminator(KeywordType.Not), "c94499cc-f088-48d3-93e8-0da61332b846"}, { new Terminator(OperatorType.Minus), "7e0f0929-19f3-42a8-b568-878a7b81617e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d63cc5e2-684c-4b4f-aee7-92fd26fc3432") },
		{ "8cab3ddd-4203-4b39-8c83-a4e2b5091c17", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "beaa2896-d18c-48ee-be91-d960be7ec684"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8cab3ddd-4203-4b39-8c83-a4e2b5091c17") },
		{ "fb2388d0-3494-49d1-abb7-388c6cbd1663", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "f9ad07b4-0f5a-477c-b2b8-2db44e8a555b"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fb2388d0-3494-49d1-abb7-388c6cbd1663") },
		{ "d5e54951-3f9e-4ae9-a357-5d0d7a933fbb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "d5e54951-3f9e-4ae9-a357-5d0d7a933fbb") },
		{ "9d50e326-11f6-4125-9791-ba15a8b836cb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "aa0b1bf2-7a48-491a-841b-ffb24b49c138"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9d50e326-11f6-4125-9791-ba15a8b836cb") },
		{ "154915c2-4bb8-4e1d-aca5-4fb6048f4adc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "154915c2-4bb8-4e1d-aca5-4fb6048f4adc") },
		{ "2391f6d1-da49-4141-9e23-0d11dc65cbdc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "2391f6d1-da49-4141-9e23-0d11dc65cbdc") },
		{ "009f921f-888c-4563-8a6d-3aa40ed9ccc0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "009f921f-888c-4563-8a6d-3aa40ed9ccc0") },
		{ "06821323-14ad-47cf-8ccb-0600fbee7306", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "06821323-14ad-47cf-8ccb-0600fbee7306") },
		{ "9d99514e-f920-460d-b3e9-9458109fbc1b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "a7671fcd-7897-4262-8394-44935d2588c0"}, { new NonTerminator(NonTerminatorType.Factor), "55259b52-bdfa-4c54-80f0-8882489977a7"}, { Terminator.NumberTerminator, "17272e2b-9263-42c1-bcfa-59955b608bdd"}, { new NonTerminator(NonTerminatorType.Variable), "ac7e5cb8-938b-47eb-aac5-d550639bec19"}, { new Terminator(DelimiterType.LeftParenthesis), "9c2fa58e-138d-4b14-9b14-9578f2fb0c6a"}, { Terminator.IdentifierTerminator, "236624af-bfe0-4a02-b536-b5f86c53bd35"}, { new Terminator(KeywordType.Not), "7c9dfa64-f1dd-46aa-9839-3d31f42f0192"}, { new Terminator(OperatorType.Minus), "404a3540-776d-4af0-a69b-e62dba9820d2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9d99514e-f920-460d-b3e9-9458109fbc1b") },
		{ "fcdcf686-3d55-46d3-90b6-471760cfec40", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "254c720a-15aa-4b41-bafd-f2dff35712ad"}, { Terminator.NumberTerminator, "17272e2b-9263-42c1-bcfa-59955b608bdd"}, { new NonTerminator(NonTerminatorType.Variable), "ac7e5cb8-938b-47eb-aac5-d550639bec19"}, { new Terminator(DelimiterType.LeftParenthesis), "9c2fa58e-138d-4b14-9b14-9578f2fb0c6a"}, { Terminator.IdentifierTerminator, "236624af-bfe0-4a02-b536-b5f86c53bd35"}, { new Terminator(KeywordType.Not), "7c9dfa64-f1dd-46aa-9839-3d31f42f0192"}, { new Terminator(OperatorType.Minus), "404a3540-776d-4af0-a69b-e62dba9820d2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fcdcf686-3d55-46d3-90b6-471760cfec40") },
		{ "1197768a-1614-43d6-a770-b0461137d52b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "e750f02c-6387-4e5b-a0b3-6e5374d49649"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1197768a-1614-43d6-a770-b0461137d52b") },
		{ "e58a7df9-7c08-48ca-a494-14b819745bdf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "9647c4c4-bf02-4c5a-a0ab-73b6664e94ba"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e58a7df9-7c08-48ca-a494-14b819745bdf") },
		{ "652fd2c2-4afa-49ea-936a-4fa8a19132f3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "652fd2c2-4afa-49ea-936a-4fa8a19132f3") },
		{ "e7291936-18c0-4d72-91d3-349e63bca94d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "6c6a4ed2-c258-4a6a-bd01-0416dcbff961"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e7291936-18c0-4d72-91d3-349e63bca94d") },
		{ "3b3e11a7-9819-4115-a921-1a06989bb22d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "3b3e11a7-9819-4115-a921-1a06989bb22d") },
		{ "3850931e-58cb-4a51-81d3-7532bb7f9dbc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "3850931e-58cb-4a51-81d3-7532bb7f9dbc") },
		{ "a3003791-a94a-4f0f-a581-2a9d0db5a207", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "a3003791-a94a-4f0f-a581-2a9d0db5a207") },
		{ "4521d328-a662-4c8f-8694-e379a042733d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "4521d328-a662-4c8f-8694-e379a042733d") },
		{ "37a1ee73-c567-409e-bdee-b33d0aae9a57", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, }, "37a1ee73-c567-409e-bdee-b33d0aae9a57") },
		{ "1e39e9b8-4548-4b80-93ee-79ff8d0c1a9c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "1e39e9b8-4548-4b80-93ee-79ff8d0c1a9c") },
		{ "8902871b-7367-4542-a832-006b3e011090", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "1684fe31-bb1a-46bf-bad2-6883745bd2b6"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "e51c215f-0ed2-4d88-837c-b418e71a11c4"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "8902871b-7367-4542-a832-006b3e011090") },
		{ "6bf5c1bc-7a00-444d-bdac-c86414b9ea3e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "8180924d-ea6e-41e9-a31a-d4e16361fc3e"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "6bf5c1bc-7a00-444d-bdac-c86414b9ea3e") },
		{ "79e3e401-f279-4a6a-9967-663e8cbb55d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "79e3e401-f279-4a6a-9967-663e8cbb55d3") },
		{ "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7") },
		{ "04c396bf-b0e6-400f-9df0-4071948f4978", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "04c396bf-b0e6-400f-9df0-4071948f4978") },
		{ "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "f706dfe3-b6b1-49d4-81bc-3e4303c49bd3"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2") },
		{ "0e7ea382-709e-41b3-b056-d4c1a3e6b051", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "6c0d4323-d95f-444b-8c9f-09498d2edbed"}, { new NonTerminator(NonTerminatorType.IdVarPart), "9b16486f-121a-4248-9a44-cfdbe57424e8"}, { new Terminator(DelimiterType.LeftSquareBracket), "f51dd719-e29c-4193-a9f9-1235c8178f3b"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "0e7ea382-709e-41b3-b056-d4c1a3e6b051") },
		{ "1a926f7d-7785-49ff-811f-c8ff008a4f77", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "484f16aa-9077-4cda-9be9-151da6275e52"}, { Terminator.NumberTerminator, "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7"}, { new NonTerminator(NonTerminatorType.Variable), "04c396bf-b0e6-400f-9df0-4071948f4978"}, { new Terminator(DelimiterType.LeftParenthesis), "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2"}, { Terminator.IdentifierTerminator, "0e7ea382-709e-41b3-b056-d4c1a3e6b051"}, { new Terminator(KeywordType.Not), "1a926f7d-7785-49ff-811f-c8ff008a4f77"}, { new Terminator(OperatorType.Minus), "ac70368d-2b3f-45d1-98e2-bbd70f25d707"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1a926f7d-7785-49ff-811f-c8ff008a4f77") },
		{ "ac70368d-2b3f-45d1-98e2-bbd70f25d707", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e8a202b6-ec19-40fe-9e8b-d0080e72e4a6"}, { Terminator.NumberTerminator, "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7"}, { new NonTerminator(NonTerminatorType.Variable), "04c396bf-b0e6-400f-9df0-4071948f4978"}, { new Terminator(DelimiterType.LeftParenthesis), "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2"}, { Terminator.IdentifierTerminator, "0e7ea382-709e-41b3-b056-d4c1a3e6b051"}, { new Terminator(KeywordType.Not), "1a926f7d-7785-49ff-811f-c8ff008a4f77"}, { new Terminator(OperatorType.Minus), "ac70368d-2b3f-45d1-98e2-bbd70f25d707"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ac70368d-2b3f-45d1-98e2-bbd70f25d707") },
		{ "f3e8d365-be88-42fd-bb71-b24a1efc6123", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "f3e8d365-be88-42fd-bb71-b24a1efc6123") },
		{ "e7cb8123-3b86-4350-bcc1-cde00bf0ea2d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "6fb766f2-8a5a-479b-b37e-e3e7dbf922cc"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e7cb8123-3b86-4350-bcc1-cde00bf0ea2d") },
		{ "cf3f049d-e11b-4bce-b0f0-70e3187c0e1e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "d5769d75-80e0-44bb-b9ea-713a4edbab61"}, { new NonTerminator(NonTerminatorType.Variable), "05c3dea6-abe5-485c-8fa4-9e7a2af0498c"}, { Terminator.IdentifierTerminator, "bf56ce79-ff0a-4859-b78f-d27987ca5b26"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "36a10a85-e2d6-4119-9b5a-21b6d9fa8c7d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "b9faa148-d99c-4da2-90bd-dc5cc36c5687"}, { new Terminator(KeywordType.If), "cc979e47-296d-4fda-82eb-96b5a942102a"}, { new Terminator(KeywordType.For), "84cd7591-19e5-4b45-be6d-22625f85cf37"}, { new Terminator(KeywordType.Begin), "8d7a1805-2634-4dc3-95e4-15207f4d8e1f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "cf3f049d-e11b-4bce-b0f0-70e3187c0e1e") },
		{ "e91935d2-8492-40d5-81a2-f57e7771db96", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "45edd5f5-e377-4550-a8db-f6dcedece1d7"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8b6a5494-2343-448c-992f-4570f3f4dc73"}, { new NonTerminator(NonTerminatorType.Term), "cdfef4a8-4523-4b63-aff2-e92c2bf95cb4"}, { new NonTerminator(NonTerminatorType.Factor), "31efe073-cd8d-4d8b-8cab-33d1e7775d29"}, { Terminator.NumberTerminator, "9047140a-81c6-48cb-b552-3e72ff88039f"}, { new NonTerminator(NonTerminatorType.Variable), "b783bbe2-0d69-4647-b122-4dcbb03b97ac"}, { new Terminator(DelimiterType.LeftParenthesis), "a4e3b184-75b6-4f8b-8606-030803eb6125"}, { Terminator.IdentifierTerminator, "2f6efa62-dde1-45e4-9ba8-cc4ae4a7ff69"}, { new Terminator(KeywordType.Not), "36de7783-58bd-4876-8056-1266ff3c75e9"}, { new Terminator(OperatorType.Minus), "62b09801-8689-4fff-9636-b6ac02ab3307"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e91935d2-8492-40d5-81a2-f57e7771db96") },
		{ "13a46cdd-dc4a-4b78-b939-9ef99ce4039a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "13a46cdd-dc4a-4b78-b939-9ef99ce4039a") },
		{ "225811d4-700a-4aa0-a97e-25c9eb154100", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "cc940d53-a724-44a1-8e60-4f3c9ead595a"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "225811d4-700a-4aa0-a97e-25c9eb154100") },
		{ "e05512fd-aa08-4f49-8d68-1f5d7c4b56e2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "e05512fd-aa08-4f49-8d68-1f5d7c4b56e2") },
		{ "8c00ad64-42a6-42b4-86fa-19329ebec708", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "8c00ad64-42a6-42b4-86fa-19329ebec708") },
		{ "5448f54e-4968-4d64-9a0a-3ad9102f27c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "bd481f70-47fe-4f13-9b85-e59663366f71"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5448f54e-4968-4d64-9a0a-3ad9102f27c2") },
		{ "b8f8e23a-4371-486c-82ea-3e2f213ffa97", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "786f4c27-869c-4701-8a93-9e1d9928410c"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b8f8e23a-4371-486c-82ea-3e2f213ffa97") },
		{ "51afb469-2974-4a34-b1f0-a3a346ef2834", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "4e48aa88-ab75-44d0-8bf6-0395eabaa0d0"}, { new NonTerminator(NonTerminatorType.Factor), "33c6d01d-f6bd-4bb3-9c1c-7357e3ffe1c6"}, { Terminator.NumberTerminator, "5e0d7b49-f9bc-4a95-8777-880cf2d47bcc"}, { new NonTerminator(NonTerminatorType.Variable), "88605b20-0e9f-458b-b47f-beb91b4c9a27"}, { new Terminator(DelimiterType.LeftParenthesis), "304939f4-4975-4778-88e7-ab611a2edc25"}, { Terminator.IdentifierTerminator, "3a89f862-6923-41cd-9727-46a014442f8b"}, { new Terminator(KeywordType.Not), "62fe6449-e173-475e-92b9-3d89f4e1e709"}, { new Terminator(OperatorType.Minus), "a5495176-f135-4105-bb6a-f12b7fa37a70"},}, new Dictionary<Terminator, ReduceInformation>{ }, "51afb469-2974-4a34-b1f0-a3a346ef2834") },
		{ "96695dea-b9fb-4972-ba90-6f5ba1cfaf16", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "9578fb3d-6d7c-404e-9914-9a5981c1a88c"}, { Terminator.NumberTerminator, "5e0d7b49-f9bc-4a95-8777-880cf2d47bcc"}, { new NonTerminator(NonTerminatorType.Variable), "88605b20-0e9f-458b-b47f-beb91b4c9a27"}, { new Terminator(DelimiterType.LeftParenthesis), "304939f4-4975-4778-88e7-ab611a2edc25"}, { Terminator.IdentifierTerminator, "3a89f862-6923-41cd-9727-46a014442f8b"}, { new Terminator(KeywordType.Not), "62fe6449-e173-475e-92b9-3d89f4e1e709"}, { new Terminator(OperatorType.Minus), "a5495176-f135-4105-bb6a-f12b7fa37a70"},}, new Dictionary<Terminator, ReduceInformation>{ }, "96695dea-b9fb-4972-ba90-6f5ba1cfaf16") },
		{ "1e5a9194-48ad-401b-aa1d-3c7e412423e2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "72321038-8a5d-4e0f-aefe-e8d38694e235"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1e5a9194-48ad-401b-aa1d-3c7e412423e2") },
		{ "b57a24ea-2c05-44aa-b7d1-c9d3afa32461", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "e096ba02-7bd0-4952-938e-4fa7bdb7f4d1"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b57a24ea-2c05-44aa-b7d1-c9d3afa32461") },
		{ "1097b4bf-51d9-4fd7-bc40-fdc04782bc48", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "1097b4bf-51d9-4fd7-bc40-fdc04782bc48") },
		{ "69868a82-92fa-42ac-937b-f252b57c547a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "b15c3175-83c8-4668-81ca-21f87c427d8d"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "69868a82-92fa-42ac-937b-f252b57c547a") },
		{ "32b5171a-2a01-4937-a4cf-fc5a186ec0e8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "32b5171a-2a01-4937-a4cf-fc5a186ec0e8") },
		{ "ffd682a7-4496-4cb2-a789-e065e964f0d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "ffd682a7-4496-4cb2-a789-e065e964f0d3") },
		{ "32385a4e-647c-46e8-a951-3f9cb44b149f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "32385a4e-647c-46e8-a951-3f9cb44b149f") },
		{ "941c2727-971a-494c-84fe-a3e1f2b740bf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "941c2727-971a-494c-84fe-a3e1f2b740bf") },
		{ "7f5e0ad7-4333-43ef-a361-fbf4d385b072", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Do), "cea0b036-1add-4d41-9fd4-b5555f8e0c0b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7f5e0ad7-4333-43ef-a361-fbf4d385b072") },
		{ "8170e558-7639-478c-b3ad-d788f869d31c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "f1ec5f34-c636-4d86-b079-becc8de7abfc"}, { new Terminator(OperatorType.Equal), "60dea2d7-d339-46dc-9fa3-d0798b7a4f5a"}, { new Terminator(OperatorType.NotEqual), "4e399383-d018-47f4-87d5-2418bf4b6b29"}, { new Terminator(OperatorType.Less), "a81a5d5f-1a88-43f2-abee-6db0fa7f3fa4"}, { new Terminator(OperatorType.LessEqual), "cf782124-1ea5-49aa-a517-45fa0ab10178"}, { new Terminator(OperatorType.Greater), "75215ba5-2f7f-4b58-a20a-4128349739eb"}, { new Terminator(OperatorType.GreaterEqual), "1e7ec66b-82ce-4ccf-860c-5162c9565f7d"}, { new NonTerminator(NonTerminatorType.AddOperator), "f56b91f8-f9ea-4b36-adad-d884db22d315"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "8170e558-7639-478c-b3ad-d788f869d31c") },
		{ "58feff7d-cb2f-46c5-b8f4-8671620139cf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "ef7c0061-08cc-4d80-8ee6-133cae45c81d"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "58feff7d-cb2f-46c5-b8f4-8671620139cf") },
		{ "5019c8be-58b7-43d8-bea8-0be597093c13", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "5019c8be-58b7-43d8-bea8-0be597093c13") },
		{ "5f5dfe62-b936-4a95-bda3-215e63344425", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "5f5dfe62-b936-4a95-bda3-215e63344425") },
		{ "ef9d65a5-871b-4e27-b850-024c266004e2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "ef9d65a5-871b-4e27-b850-024c266004e2") },
		{ "8b3d0c2a-df98-4667-98cf-6de6d74d4910", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "b8444c08-0d91-4dec-b165-a3b680b74e46"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8b3d0c2a-df98-4667-98cf-6de6d74d4910") },
		{ "24b5a051-ab9e-4a1e-bd34-82fe7c82cede", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "33c8ffe9-85c5-4cb6-b2ce-6f51eafb6c5f"}, { new NonTerminator(NonTerminatorType.IdVarPart), "0c7ba21a-fcfe-4b62-9ac8-3a98f2a197cc"}, { new Terminator(DelimiterType.LeftSquareBracket), "282b6b73-a086-4c63-ae6a-94b4fcf94802"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "24b5a051-ab9e-4a1e-bd34-82fe7c82cede") },
		{ "bc126c07-4e05-405b-8214-47da44b79eb3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3b837d8a-f71b-4efd-a09c-1307893f4722"}, { Terminator.NumberTerminator, "5f5dfe62-b936-4a95-bda3-215e63344425"}, { new NonTerminator(NonTerminatorType.Variable), "ef9d65a5-871b-4e27-b850-024c266004e2"}, { new Terminator(DelimiterType.LeftParenthesis), "8b3d0c2a-df98-4667-98cf-6de6d74d4910"}, { Terminator.IdentifierTerminator, "24b5a051-ab9e-4a1e-bd34-82fe7c82cede"}, { new Terminator(KeywordType.Not), "bc126c07-4e05-405b-8214-47da44b79eb3"}, { new Terminator(OperatorType.Minus), "bad4d95a-9b87-4d9d-89b3-2f81d055bac4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bc126c07-4e05-405b-8214-47da44b79eb3") },
		{ "bad4d95a-9b87-4d9d-89b3-2f81d055bac4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "025d9f84-a417-4594-8a53-e845f533429b"}, { Terminator.NumberTerminator, "5f5dfe62-b936-4a95-bda3-215e63344425"}, { new NonTerminator(NonTerminatorType.Variable), "ef9d65a5-871b-4e27-b850-024c266004e2"}, { new Terminator(DelimiterType.LeftParenthesis), "8b3d0c2a-df98-4667-98cf-6de6d74d4910"}, { Terminator.IdentifierTerminator, "24b5a051-ab9e-4a1e-bd34-82fe7c82cede"}, { new Terminator(KeywordType.Not), "bc126c07-4e05-405b-8214-47da44b79eb3"}, { new Terminator(OperatorType.Minus), "bad4d95a-9b87-4d9d-89b3-2f81d055bac4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bad4d95a-9b87-4d9d-89b3-2f81d055bac4") },
		{ "cd4b0d85-9096-4087-a054-2ca1a4a09b1f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "2e34b847-1586-4015-8a37-df539ba86751"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "cd4b0d85-9096-4087-a054-2ca1a4a09b1f") },
		{ "52319dd3-e4cb-42a1-8b15-3946994631b3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "07457ebc-9712-453b-8bb6-784d3af2ddeb"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "52319dd3-e4cb-42a1-8b15-3946994631b3") },
		{ "7dc12ae0-4efc-42ff-9512-0a99162124c0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "7dc12ae0-4efc-42ff-9512-0a99162124c0") },
		{ "4ef11303-cb21-4535-85fa-cb490faac422", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "4ef11303-cb21-4535-85fa-cb490faac422") },
		{ "16358e64-c0a2-43c1-9ab7-e1d9327495e0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "16358e64-c0a2-43c1-9ab7-e1d9327495e0") },
		{ "d65c4055-3e12-492d-9a71-870e92cc47b1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "32aef41a-76b6-46f7-b762-21cb0447e168"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d65c4055-3e12-492d-9a71-870e92cc47b1") },
		{ "b3001572-4edd-4505-a8a0-ece02b06990e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "228838c6-0b26-4c0c-b7ec-fe6e5f95555b"}, { new NonTerminator(NonTerminatorType.IdVarPart), "fa3fc55c-54fe-4680-87c6-46e21d90fa1d"}, { new Terminator(DelimiterType.LeftSquareBracket), "dbba69d5-f59f-4386-b561-e89d9ee1c68d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "b3001572-4edd-4505-a8a0-ece02b06990e") },
		{ "84e9d49f-1787-4946-8fab-c3d912cfd7d5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "6df498dd-37cb-495d-902e-d32ebdade60a"}, { Terminator.NumberTerminator, "4ef11303-cb21-4535-85fa-cb490faac422"}, { new NonTerminator(NonTerminatorType.Variable), "16358e64-c0a2-43c1-9ab7-e1d9327495e0"}, { new Terminator(DelimiterType.LeftParenthesis), "d65c4055-3e12-492d-9a71-870e92cc47b1"}, { Terminator.IdentifierTerminator, "b3001572-4edd-4505-a8a0-ece02b06990e"}, { new Terminator(KeywordType.Not), "84e9d49f-1787-4946-8fab-c3d912cfd7d5"}, { new Terminator(OperatorType.Minus), "2fc476a5-3b8a-49f9-8c19-d1ca68bfb821"},}, new Dictionary<Terminator, ReduceInformation>{ }, "84e9d49f-1787-4946-8fab-c3d912cfd7d5") },
		{ "2fc476a5-3b8a-49f9-8c19-d1ca68bfb821", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "8eaf616d-00e3-4c67-9dc6-232b764107f6"}, { Terminator.NumberTerminator, "4ef11303-cb21-4535-85fa-cb490faac422"}, { new NonTerminator(NonTerminatorType.Variable), "16358e64-c0a2-43c1-9ab7-e1d9327495e0"}, { new Terminator(DelimiterType.LeftParenthesis), "d65c4055-3e12-492d-9a71-870e92cc47b1"}, { Terminator.IdentifierTerminator, "b3001572-4edd-4505-a8a0-ece02b06990e"}, { new Terminator(KeywordType.Not), "84e9d49f-1787-4946-8fab-c3d912cfd7d5"}, { new Terminator(OperatorType.Minus), "2fc476a5-3b8a-49f9-8c19-d1ca68bfb821"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2fc476a5-3b8a-49f9-8c19-d1ca68bfb821") },
		{ "8e30d65d-8ffd-49ef-8231-da25634b6748", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "11c433af-6913-4b14-8864-c238218e7f61"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "8e30d65d-8ffd-49ef-8231-da25634b6748") },
		{ "137702b9-425d-4547-8c6e-9f59730f6091", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "137702b9-425d-4547-8c6e-9f59730f6091") },
		{ "2348e9b4-af41-46cf-87be-af281dc23e2a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "2348e9b4-af41-46cf-87be-af281dc23e2a") },
		{ "ab33677c-e8b4-4058-b769-d04e0880af7a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "39b35b19-e990-4f14-bc2a-6608449f5ca1"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ab33677c-e8b4-4058-b769-d04e0880af7a") },
		{ "cfa9c33f-64c6-42b1-b14a-2a59a8aa26fe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "c68999e7-b479-4550-910b-7dafd04b3373"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cfa9c33f-64c6-42b1-b14a-2a59a8aa26fe") },
		{ "7ef948bb-4168-4668-b0c7-2657a3495568", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "7ef948bb-4168-4668-b0c7-2657a3495568") },
		{ "0f36db83-65d1-4f20-a7ae-9d7ece62b66c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(6, new NonTerminator(NonTerminatorType.Type))}, }, "0f36db83-65d1-4f20-a7ae-9d7ece62b66c") },
		{ "7b6d3a54-b68b-4a49-a034-4d20cefeadf4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "014ef03e-d055-4b36-a9d7-c5a15df1aa84"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7b6d3a54-b68b-4a49-a034-4d20cefeadf4") },
		{ "a72b4a5d-fde1-4bf5-ba12-51afdef59ab1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "6d62c2d9-622b-47c0-966b-376605d27cbb"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "a72b4a5d-fde1-4bf5-ba12-51afdef59ab1") },
		{ "2e6e51a4-c9a2-4e5b-b40f-e006bb9cb9ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "2e6e51a4-c9a2-4e5b-b40f-e006bb9cb9ff") },
		{ "e9af9eaf-ff2c-4af6-b253-16ece4ccfa54", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "e9af9eaf-ff2c-4af6-b253-16ece4ccfa54") },
		{ "32a59706-cf5b-48b6-b352-4a6e9e31da8a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "912cba8b-b5f2-4dc5-88d4-5a52db814534"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "32a59706-cf5b-48b6-b352-4a6e9e31da8a") },
		{ "65125b6e-f75f-4b8e-96f1-a50a34ba35fe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "829a0cc2-e7a0-4eb9-9525-7b50d37aa861"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "65125b6e-f75f-4b8e-96f1-a50a34ba35fe") },
		{ "47fad12d-892b-4216-9ffb-8792b4d7b4ee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d63cc5e2-684c-4b4f-aee7-92fd26fc3432"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "47fad12d-892b-4216-9ffb-8792b4d7b4ee") },
		{ "9833770b-ce8e-4df0-b89f-15c5c018c032", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "9833770b-ce8e-4df0-b89f-15c5c018c032") },
		{ "beaa2896-d18c-48ee-be91-d960be7ec684", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "beaa2896-d18c-48ee-be91-d960be7ec684") },
		{ "f9ad07b4-0f5a-477c-b2b8-2db44e8a555b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "e7684ea4-0849-45c8-9d17-a884b1fd4d12"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f9ad07b4-0f5a-477c-b2b8-2db44e8a555b") },
		{ "aa0b1bf2-7a48-491a-841b-ffb24b49c138", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "9012ab07-6197-4c61-a1fc-10cd68ec4b23"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "aa0b1bf2-7a48-491a-841b-ffb24b49c138") },
		{ "a7671fcd-7897-4262-8394-44935d2588c0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "fcdcf686-3d55-46d3-90b6-471760cfec40"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "a7671fcd-7897-4262-8394-44935d2588c0") },
		{ "254c720a-15aa-4b41-bafd-f2dff35712ad", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "254c720a-15aa-4b41-bafd-f2dff35712ad") },
		{ "e750f02c-6387-4e5b-a0b3-6e5374d49649", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "e750f02c-6387-4e5b-a0b3-6e5374d49649") },
		{ "9647c4c4-bf02-4c5a-a0ab-73b6664e94ba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "37865dbb-9cdc-49b8-81f5-6fcd007774e5"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9647c4c4-bf02-4c5a-a0ab-73b6664e94ba") },
		{ "6c6a4ed2-c258-4a6a-bd01-0416dcbff961", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "767db543-9264-4a26-bdf3-5df32b786fa5"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6c6a4ed2-c258-4a6a-bd01-0416dcbff961") },
		{ "1684fe31-bb1a-46bf-bad2-6883745bd2b6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "84fe2ad8-6a35-4684-975b-4ef4f8e132f9"}, { new NonTerminator(NonTerminatorType.Term), "e010b72a-d564-4964-ba27-682d1751b0cc"}, { new NonTerminator(NonTerminatorType.Factor), "84bcb458-c266-4cd2-9243-3e037e493e90"}, { Terminator.NumberTerminator, "51e290b6-37e0-4cf3-b311-247de1a5e819"}, { new NonTerminator(NonTerminatorType.Variable), "7962cf3c-2542-413f-b317-280262bc110e"}, { new Terminator(DelimiterType.LeftParenthesis), "d762ead4-77ea-4d13-83ce-bd2ef66c871e"}, { Terminator.IdentifierTerminator, "360d64a9-cbd4-47f4-ae8e-c581c007d4e6"}, { new Terminator(KeywordType.Not), "927a5bc5-bef9-416f-ab4f-ca5c55787148"}, { new Terminator(OperatorType.Minus), "be3688dc-6d78-4b4a-ab01-cde694894c1c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1684fe31-bb1a-46bf-bad2-6883745bd2b6") },
		{ "e51c215f-0ed2-4d88-837c-b418e71a11c4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "82d50dad-9458-4a11-b463-d6536fd389c5"}, { new NonTerminator(NonTerminatorType.Factor), "79e3e401-f279-4a6a-9967-663e8cbb55d3"}, { Terminator.NumberTerminator, "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7"}, { new NonTerminator(NonTerminatorType.Variable), "04c396bf-b0e6-400f-9df0-4071948f4978"}, { new Terminator(DelimiterType.LeftParenthesis), "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2"}, { Terminator.IdentifierTerminator, "0e7ea382-709e-41b3-b056-d4c1a3e6b051"}, { new Terminator(KeywordType.Not), "1a926f7d-7785-49ff-811f-c8ff008a4f77"}, { new Terminator(OperatorType.Minus), "ac70368d-2b3f-45d1-98e2-bbd70f25d707"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e51c215f-0ed2-4d88-837c-b418e71a11c4") },
		{ "8180924d-ea6e-41e9-a31a-d4e16361fc3e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "c222e7fe-a0bc-473b-92c7-ad6e1e6993a5"}, { Terminator.NumberTerminator, "a8d8c9fc-5ea8-4777-aefe-1a56eaaab2c7"}, { new NonTerminator(NonTerminatorType.Variable), "04c396bf-b0e6-400f-9df0-4071948f4978"}, { new Terminator(DelimiterType.LeftParenthesis), "e32aad5e-8f77-414f-aec1-f8b8a5d40ca2"}, { Terminator.IdentifierTerminator, "0e7ea382-709e-41b3-b056-d4c1a3e6b051"}, { new Terminator(KeywordType.Not), "1a926f7d-7785-49ff-811f-c8ff008a4f77"}, { new Terminator(OperatorType.Minus), "ac70368d-2b3f-45d1-98e2-bbd70f25d707"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8180924d-ea6e-41e9-a31a-d4e16361fc3e") },
		{ "f706dfe3-b6b1-49d4-81bc-3e4303c49bd3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "b0a3adaa-a33e-462e-831a-e6b5d1d606cc"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f706dfe3-b6b1-49d4-81bc-3e4303c49bd3") },
		{ "6c0d4323-d95f-444b-8c9f-09498d2edbed", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "721b32a4-61ae-47a4-a247-4d66ac9aac9e"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6c0d4323-d95f-444b-8c9f-09498d2edbed") },
		{ "9b16486f-121a-4248-9a44-cfdbe57424e8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "9b16486f-121a-4248-9a44-cfdbe57424e8") },
		{ "f51dd719-e29c-4193-a9f9-1235c8178f3b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "cc4994b5-1c7f-4d8e-b8d4-bd09321a5fe2"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f51dd719-e29c-4193-a9f9-1235c8178f3b") },
		{ "484f16aa-9077-4cda-9be9-151da6275e52", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "484f16aa-9077-4cda-9be9-151da6275e52") },
		{ "e8a202b6-ec19-40fe-9e8b-d0080e72e4a6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "e8a202b6-ec19-40fe-9e8b-d0080e72e4a6") },
		{ "6fb766f2-8a5a-479b-b37e-e3e7dbf922cc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "6fb766f2-8a5a-479b-b37e-e3e7dbf922cc") },
		{ "d5769d75-80e0-44bb-b9ea-713a4edbab61", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ElsePart), "45f3dcfe-a3ef-4929-915f-68f8b996e544"}, { new Terminator(KeywordType.Else), "aa5f894f-6bed-40f5-9b05-03668961d048"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, }, "d5769d75-80e0-44bb-b9ea-713a4edbab61") },
		{ "45edd5f5-e377-4550-a8db-f6dcedece1d7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.To), "2a6d72e9-1536-41cc-89d0-c738804d4210"},}, new Dictionary<Terminator, ReduceInformation>{ }, "45edd5f5-e377-4550-a8db-f6dcedece1d7") },
		{ "bd481f70-47fe-4f13-9b85-e59663366f71", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "bd481f70-47fe-4f13-9b85-e59663366f71") },
		{ "786f4c27-869c-4701-8a93-9e1d9928410c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "786f4c27-869c-4701-8a93-9e1d9928410c") },
		{ "4e48aa88-ab75-44d0-8bf6-0395eabaa0d0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "96695dea-b9fb-4972-ba90-6f5ba1cfaf16"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "4e48aa88-ab75-44d0-8bf6-0395eabaa0d0") },
		{ "9578fb3d-6d7c-404e-9914-9a5981c1a88c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "9578fb3d-6d7c-404e-9914-9a5981c1a88c") },
		{ "72321038-8a5d-4e0f-aefe-e8d38694e235", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "72321038-8a5d-4e0f-aefe-e8d38694e235") },
		{ "e096ba02-7bd0-4952-938e-4fa7bdb7f4d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "067ec989-9cc2-443c-bd87-907c2b912ebd"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e096ba02-7bd0-4952-938e-4fa7bdb7f4d1") },
		{ "b15c3175-83c8-4668-81ca-21f87c427d8d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "d82c7b40-5ee9-4789-bc31-54d95ae33416"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b15c3175-83c8-4668-81ca-21f87c427d8d") },
		{ "cea0b036-1add-4d41-9fd4-b5555f8e0c0b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "c0365d1c-2473-4ed3-9655-cef35b85251b"}, { new NonTerminator(NonTerminatorType.Variable), "112924ad-56a4-4b25-b473-3719cf9f146d"}, { Terminator.IdentifierTerminator, "2ca36d82-352b-460d-9a9c-3820d154ae40"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "fdc408d0-ab70-4f3a-a6cc-948dcefd9bec"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "7a6f8cbf-bf57-4d0d-8f88-f51b3ff6cb72"}, { new Terminator(KeywordType.If), "73074719-3be9-46aa-80f3-1e8ee6a9b24b"}, { new Terminator(KeywordType.For), "a53fc2b7-1c76-4892-aefa-96321460277b"}, { new Terminator(KeywordType.Begin), "387138b7-6e8b-4b44-b497-4da7e03d863a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "cea0b036-1add-4d41-9fd4-b5555f8e0c0b") },
		{ "f1ec5f34-c636-4d86-b079-becc8de7abfc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "8ad801f5-31a8-4d66-a98e-910487c088a1"}, { new NonTerminator(NonTerminatorType.Term), "d2dc372a-a287-45cc-a592-d90865568bfb"}, { new NonTerminator(NonTerminatorType.Factor), "2011e414-cfed-4833-855a-e926e29005b1"}, { Terminator.NumberTerminator, "3dc4f03e-bcbe-4f0d-bbd5-9830a09661c4"}, { new NonTerminator(NonTerminatorType.Variable), "422611f6-1fa9-4a81-8015-a7fac922d1c3"}, { new Terminator(DelimiterType.LeftParenthesis), "78cca9ee-10ea-4165-bed3-45ccebd8753f"}, { Terminator.IdentifierTerminator, "31a64221-d8c9-4a33-936b-76f0337941b9"}, { new Terminator(KeywordType.Not), "c0b190f8-cfb2-426c-8a63-16f3a632b49b"}, { new Terminator(OperatorType.Minus), "73325f12-9d72-4578-9dc9-489597376504"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f1ec5f34-c636-4d86-b079-becc8de7abfc") },
		{ "f56b91f8-f9ea-4b36-adad-d884db22d315", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "66aef84a-c4df-4151-b26c-6cab28af96c1"}, { new NonTerminator(NonTerminatorType.Factor), "5019c8be-58b7-43d8-bea8-0be597093c13"}, { Terminator.NumberTerminator, "5f5dfe62-b936-4a95-bda3-215e63344425"}, { new NonTerminator(NonTerminatorType.Variable), "ef9d65a5-871b-4e27-b850-024c266004e2"}, { new Terminator(DelimiterType.LeftParenthesis), "8b3d0c2a-df98-4667-98cf-6de6d74d4910"}, { Terminator.IdentifierTerminator, "24b5a051-ab9e-4a1e-bd34-82fe7c82cede"}, { new Terminator(KeywordType.Not), "bc126c07-4e05-405b-8214-47da44b79eb3"}, { new Terminator(OperatorType.Minus), "bad4d95a-9b87-4d9d-89b3-2f81d055bac4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f56b91f8-f9ea-4b36-adad-d884db22d315") },
		{ "ef7c0061-08cc-4d80-8ee6-133cae45c81d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "652f8b39-10a5-49b4-8ced-2889862568df"}, { Terminator.NumberTerminator, "5f5dfe62-b936-4a95-bda3-215e63344425"}, { new NonTerminator(NonTerminatorType.Variable), "ef9d65a5-871b-4e27-b850-024c266004e2"}, { new Terminator(DelimiterType.LeftParenthesis), "8b3d0c2a-df98-4667-98cf-6de6d74d4910"}, { Terminator.IdentifierTerminator, "24b5a051-ab9e-4a1e-bd34-82fe7c82cede"}, { new Terminator(KeywordType.Not), "bc126c07-4e05-405b-8214-47da44b79eb3"}, { new Terminator(OperatorType.Minus), "bad4d95a-9b87-4d9d-89b3-2f81d055bac4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ef7c0061-08cc-4d80-8ee6-133cae45c81d") },
		{ "b8444c08-0d91-4dec-b165-a3b680b74e46", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "bc6b7a63-88f4-4eeb-94db-f3677b3aa77b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b8444c08-0d91-4dec-b165-a3b680b74e46") },
		{ "33c8ffe9-85c5-4cb6-b2ce-6f51eafb6c5f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "63820e3b-5e68-4e48-97db-b7b82f09ce2f"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "33c8ffe9-85c5-4cb6-b2ce-6f51eafb6c5f") },
		{ "0c7ba21a-fcfe-4b62-9ac8-3a98f2a197cc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "0c7ba21a-fcfe-4b62-9ac8-3a98f2a197cc") },
		{ "282b6b73-a086-4c63-ae6a-94b4fcf94802", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "af567331-93f4-4450-9f7d-3b236bebd07a"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "282b6b73-a086-4c63-ae6a-94b4fcf94802") },
		{ "3b837d8a-f71b-4efd-a09c-1307893f4722", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "3b837d8a-f71b-4efd-a09c-1307893f4722") },
		{ "025d9f84-a417-4594-8a53-e845f533429b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "025d9f84-a417-4594-8a53-e845f533429b") },
		{ "2e34b847-1586-4015-8a37-df539ba86751", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "07d9d974-ab84-4710-81d3-7f20c94c4017"}, { new NonTerminator(NonTerminatorType.Factor), "7dc12ae0-4efc-42ff-9512-0a99162124c0"}, { Terminator.NumberTerminator, "4ef11303-cb21-4535-85fa-cb490faac422"}, { new NonTerminator(NonTerminatorType.Variable), "16358e64-c0a2-43c1-9ab7-e1d9327495e0"}, { new Terminator(DelimiterType.LeftParenthesis), "d65c4055-3e12-492d-9a71-870e92cc47b1"}, { Terminator.IdentifierTerminator, "b3001572-4edd-4505-a8a0-ece02b06990e"}, { new Terminator(KeywordType.Not), "84e9d49f-1787-4946-8fab-c3d912cfd7d5"}, { new Terminator(OperatorType.Minus), "2fc476a5-3b8a-49f9-8c19-d1ca68bfb821"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2e34b847-1586-4015-8a37-df539ba86751") },
		{ "07457ebc-9712-453b-8bb6-784d3af2ddeb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "4dd0d283-371b-484a-8255-b8b94961d7b2"}, { Terminator.NumberTerminator, "4ef11303-cb21-4535-85fa-cb490faac422"}, { new NonTerminator(NonTerminatorType.Variable), "16358e64-c0a2-43c1-9ab7-e1d9327495e0"}, { new Terminator(DelimiterType.LeftParenthesis), "d65c4055-3e12-492d-9a71-870e92cc47b1"}, { Terminator.IdentifierTerminator, "b3001572-4edd-4505-a8a0-ece02b06990e"}, { new Terminator(KeywordType.Not), "84e9d49f-1787-4946-8fab-c3d912cfd7d5"}, { new Terminator(OperatorType.Minus), "2fc476a5-3b8a-49f9-8c19-d1ca68bfb821"},}, new Dictionary<Terminator, ReduceInformation>{ }, "07457ebc-9712-453b-8bb6-784d3af2ddeb") },
		{ "32aef41a-76b6-46f7-b762-21cb0447e168", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "881259a9-2d36-4f8f-a614-631d9df084d1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "32aef41a-76b6-46f7-b762-21cb0447e168") },
		{ "228838c6-0b26-4c0c-b7ec-fe6e5f95555b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "641454df-ca11-46e6-92d5-b7172abbb85e"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "228838c6-0b26-4c0c-b7ec-fe6e5f95555b") },
		{ "fa3fc55c-54fe-4680-87c6-46e21d90fa1d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "fa3fc55c-54fe-4680-87c6-46e21d90fa1d") },
		{ "dbba69d5-f59f-4386-b561-e89d9ee1c68d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "011c3396-81ce-4fe3-9856-84b69764a78f"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dbba69d5-f59f-4386-b561-e89d9ee1c68d") },
		{ "6df498dd-37cb-495d-902e-d32ebdade60a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "6df498dd-37cb-495d-902e-d32ebdade60a") },
		{ "8eaf616d-00e3-4c67-9dc6-232b764107f6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "8eaf616d-00e3-4c67-9dc6-232b764107f6") },
		{ "39b35b19-e990-4f14-bc2a-6608449f5ca1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "39b35b19-e990-4f14-bc2a-6608449f5ca1") },
		{ "c68999e7-b479-4550-910b-7dafd04b3373", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "c68999e7-b479-4550-910b-7dafd04b3373") },
		{ "014ef03e-d055-4b36-a9d7-c5a15df1aa84", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Period))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Period))}, }, "014ef03e-d055-4b36-a9d7-c5a15df1aa84") },
		{ "912cba8b-b5f2-4dc5-88d4-5a52db814534", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "912cba8b-b5f2-4dc5-88d4-5a52db814534") },
		{ "829a0cc2-e7a0-4eb9-9525-7b50d37aa861", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "829a0cc2-e7a0-4eb9-9525-7b50d37aa861") },
		{ "e7684ea4-0849-45c8-9d17-a884b1fd4d12", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "e7684ea4-0849-45c8-9d17-a884b1fd4d12") },
		{ "9012ab07-6197-4c61-a1fc-10cd68ec4b23", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "9012ab07-6197-4c61-a1fc-10cd68ec4b23") },
		{ "37865dbb-9cdc-49b8-81f5-6fcd007774e5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "37865dbb-9cdc-49b8-81f5-6fcd007774e5") },
		{ "767db543-9264-4a26-bdf3-5df32b786fa5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "767db543-9264-4a26-bdf3-5df32b786fa5") },
		{ "84fe2ad8-6a35-4684-975b-4ef4f8e132f9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "fee56828-0e35-4559-841b-738ee6f970fd"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "84fe2ad8-6a35-4684-975b-4ef4f8e132f9") },
		{ "e010b72a-d564-4964-ba27-682d1751b0cc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "a8c4264f-1575-4ac5-b12e-44888e8b3877"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "e010b72a-d564-4964-ba27-682d1751b0cc") },
		{ "84bcb458-c266-4cd2-9243-3e037e493e90", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "84bcb458-c266-4cd2-9243-3e037e493e90") },
		{ "51e290b6-37e0-4cf3-b311-247de1a5e819", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "51e290b6-37e0-4cf3-b311-247de1a5e819") },
		{ "7962cf3c-2542-413f-b317-280262bc110e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "7962cf3c-2542-413f-b317-280262bc110e") },
		{ "d762ead4-77ea-4d13-83ce-bd2ef66c871e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "d6aaf87c-cd5e-4598-8733-261c6eb02766"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d762ead4-77ea-4d13-83ce-bd2ef66c871e") },
		{ "360d64a9-cbd4-47f4-ae8e-c581c007d4e6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "a161984a-5a7a-4db6-8523-9e94528f7847"}, { new NonTerminator(NonTerminatorType.IdVarPart), "686a1337-616c-483c-ae57-da9aa186a476"}, { new Terminator(DelimiterType.LeftSquareBracket), "605b0134-7c11-4d34-bb23-3ad2b64e7a3f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "360d64a9-cbd4-47f4-ae8e-c581c007d4e6") },
		{ "927a5bc5-bef9-416f-ab4f-ca5c55787148", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "17d6b0c9-9d43-4805-9502-9b66d4ab4826"}, { Terminator.NumberTerminator, "51e290b6-37e0-4cf3-b311-247de1a5e819"}, { new NonTerminator(NonTerminatorType.Variable), "7962cf3c-2542-413f-b317-280262bc110e"}, { new Terminator(DelimiterType.LeftParenthesis), "d762ead4-77ea-4d13-83ce-bd2ef66c871e"}, { Terminator.IdentifierTerminator, "360d64a9-cbd4-47f4-ae8e-c581c007d4e6"}, { new Terminator(KeywordType.Not), "927a5bc5-bef9-416f-ab4f-ca5c55787148"}, { new Terminator(OperatorType.Minus), "be3688dc-6d78-4b4a-ab01-cde694894c1c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "927a5bc5-bef9-416f-ab4f-ca5c55787148") },
		{ "be3688dc-6d78-4b4a-ab01-cde694894c1c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e159a84d-b36c-46a7-ba1d-58495ceb09cb"}, { Terminator.NumberTerminator, "51e290b6-37e0-4cf3-b311-247de1a5e819"}, { new NonTerminator(NonTerminatorType.Variable), "7962cf3c-2542-413f-b317-280262bc110e"}, { new Terminator(DelimiterType.LeftParenthesis), "d762ead4-77ea-4d13-83ce-bd2ef66c871e"}, { Terminator.IdentifierTerminator, "360d64a9-cbd4-47f4-ae8e-c581c007d4e6"}, { new Terminator(KeywordType.Not), "927a5bc5-bef9-416f-ab4f-ca5c55787148"}, { new Terminator(OperatorType.Minus), "be3688dc-6d78-4b4a-ab01-cde694894c1c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "be3688dc-6d78-4b4a-ab01-cde694894c1c") },
		{ "82d50dad-9458-4a11-b463-d6536fd389c5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "8180924d-ea6e-41e9-a31a-d4e16361fc3e"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "82d50dad-9458-4a11-b463-d6536fd389c5") },
		{ "c222e7fe-a0bc-473b-92c7-ad6e1e6993a5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "c222e7fe-a0bc-473b-92c7-ad6e1e6993a5") },
		{ "b0a3adaa-a33e-462e-831a-e6b5d1d606cc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "b0a3adaa-a33e-462e-831a-e6b5d1d606cc") },
		{ "721b32a4-61ae-47a4-a247-4d66ac9aac9e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "f489c0fc-d63f-4a65-8045-bd4a8882bac4"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "721b32a4-61ae-47a4-a247-4d66ac9aac9e") },
		{ "cc4994b5-1c7f-4d8e-b8d4-bd09321a5fe2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "37ed8009-1a61-4dce-a2ec-2fecd6db8dd5"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cc4994b5-1c7f-4d8e-b8d4-bd09321a5fe2") },
		{ "45f3dcfe-a3ef-4929-915f-68f8b996e544", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, }, "45f3dcfe-a3ef-4929-915f-68f8b996e544") },
		{ "aa5f894f-6bed-40f5-9b05-03668961d048", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "67d065f5-7da8-4743-8ae1-7a4e6c033176"}, { new NonTerminator(NonTerminatorType.Variable), "05c3dea6-abe5-485c-8fa4-9e7a2af0498c"}, { Terminator.IdentifierTerminator, "bf56ce79-ff0a-4859-b78f-d27987ca5b26"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "36a10a85-e2d6-4119-9b5a-21b6d9fa8c7d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "b9faa148-d99c-4da2-90bd-dc5cc36c5687"}, { new Terminator(KeywordType.If), "cc979e47-296d-4fda-82eb-96b5a942102a"}, { new Terminator(KeywordType.For), "84cd7591-19e5-4b45-be6d-22625f85cf37"}, { new Terminator(KeywordType.Begin), "8d7a1805-2634-4dc3-95e4-15207f4d8e1f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "aa5f894f-6bed-40f5-9b05-03668961d048") },
		{ "2a6d72e9-1536-41cc-89d0-c738804d4210", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "1be0aafd-43a2-4ee9-be4f-7969000cce98"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8170e558-7639-478c-b3ad-d788f869d31c"}, { new NonTerminator(NonTerminatorType.Term), "58feff7d-cb2f-46c5-b8f4-8671620139cf"}, { new NonTerminator(NonTerminatorType.Factor), "5019c8be-58b7-43d8-bea8-0be597093c13"}, { Terminator.NumberTerminator, "5f5dfe62-b936-4a95-bda3-215e63344425"}, { new NonTerminator(NonTerminatorType.Variable), "ef9d65a5-871b-4e27-b850-024c266004e2"}, { new Terminator(DelimiterType.LeftParenthesis), "8b3d0c2a-df98-4667-98cf-6de6d74d4910"}, { Terminator.IdentifierTerminator, "24b5a051-ab9e-4a1e-bd34-82fe7c82cede"}, { new Terminator(KeywordType.Not), "bc126c07-4e05-405b-8214-47da44b79eb3"}, { new Terminator(OperatorType.Minus), "bad4d95a-9b87-4d9d-89b3-2f81d055bac4"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2a6d72e9-1536-41cc-89d0-c738804d4210") },
		{ "067ec989-9cc2-443c-bd87-907c2b912ebd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "067ec989-9cc2-443c-bd87-907c2b912ebd") },
		{ "d82c7b40-5ee9-4789-bc31-54d95ae33416", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "d82c7b40-5ee9-4789-bc31-54d95ae33416") },
		{ "c0365d1c-2473-4ed3-9655-cef35b85251b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, }, "c0365d1c-2473-4ed3-9655-cef35b85251b") },
		{ "8ad801f5-31a8-4d66-a98e-910487c088a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "32d24d83-e9bb-4ca3-a2a7-4857f740029f"}, { new Terminator(OperatorType.Plus), "38822c33-4ba5-4392-ba95-563f93b165e7"}, { new Terminator(OperatorType.Minus), "6f247b41-6a05-41b6-9d79-ead414b3e4c7"}, { new Terminator(KeywordType.Or), "3c259c6f-e75c-4280-b176-95d6a084bd3d"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "8ad801f5-31a8-4d66-a98e-910487c088a1") },
		{ "d2dc372a-a287-45cc-a592-d90865568bfb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "dea17e32-ed88-42ee-95cd-fe2cb1d561d2"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "d2dc372a-a287-45cc-a592-d90865568bfb") },
		{ "2011e414-cfed-4833-855a-e926e29005b1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "2011e414-cfed-4833-855a-e926e29005b1") },
		{ "3dc4f03e-bcbe-4f0d-bbd5-9830a09661c4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "3dc4f03e-bcbe-4f0d-bbd5-9830a09661c4") },
		{ "422611f6-1fa9-4a81-8015-a7fac922d1c3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "422611f6-1fa9-4a81-8015-a7fac922d1c3") },
		{ "78cca9ee-10ea-4165-bed3-45ccebd8753f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "04420f81-c239-4ead-af8f-706696a77692"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "079b7b79-612b-4966-9a45-a29921890ddc"}, { new NonTerminator(NonTerminatorType.Term), "64ca8901-7e44-43f8-aa05-19618ec7272e"}, { new NonTerminator(NonTerminatorType.Factor), "87a8bb69-0783-4472-a058-62990d79c1e7"}, { Terminator.NumberTerminator, "4f2f81a3-31ae-4ab2-93d6-456e60b8e8de"}, { new NonTerminator(NonTerminatorType.Variable), "ed2faab9-002b-4f70-a59d-4b6545a4c182"}, { new Terminator(DelimiterType.LeftParenthesis), "473cdb76-aded-49c1-83cf-f8f138d8133a"}, { Terminator.IdentifierTerminator, "a4a0dffd-a8f4-4c3c-81a5-4f8265d4c3f0"}, { new Terminator(KeywordType.Not), "b9e61a85-f306-47f3-816b-781c46782d33"}, { new Terminator(OperatorType.Minus), "cdd3a5b5-1547-4278-b7d6-3f830faa954b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "78cca9ee-10ea-4165-bed3-45ccebd8753f") },
		{ "31a64221-d8c9-4a33-936b-76f0337941b9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "8fee768d-6560-49a0-b12b-cd997fe28b91"}, { new NonTerminator(NonTerminatorType.IdVarPart), "3bd432d4-d808-4461-b79e-be0928ede65f"}, { new Terminator(DelimiterType.LeftSquareBracket), "145b205d-5cfa-41e8-8955-b37a0912bb14"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "31a64221-d8c9-4a33-936b-76f0337941b9") },
		{ "c0b190f8-cfb2-426c-8a63-16f3a632b49b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "a25f790d-1583-4815-aa3e-5a8fc47b52f0"}, { Terminator.NumberTerminator, "3dc4f03e-bcbe-4f0d-bbd5-9830a09661c4"}, { new NonTerminator(NonTerminatorType.Variable), "422611f6-1fa9-4a81-8015-a7fac922d1c3"}, { new Terminator(DelimiterType.LeftParenthesis), "78cca9ee-10ea-4165-bed3-45ccebd8753f"}, { Terminator.IdentifierTerminator, "31a64221-d8c9-4a33-936b-76f0337941b9"}, { new Terminator(KeywordType.Not), "c0b190f8-cfb2-426c-8a63-16f3a632b49b"}, { new Terminator(OperatorType.Minus), "73325f12-9d72-4578-9dc9-489597376504"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c0b190f8-cfb2-426c-8a63-16f3a632b49b") },
		{ "73325f12-9d72-4578-9dc9-489597376504", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "03d7a6b0-0d6c-465a-a0df-06accd17df6c"}, { Terminator.NumberTerminator, "3dc4f03e-bcbe-4f0d-bbd5-9830a09661c4"}, { new NonTerminator(NonTerminatorType.Variable), "422611f6-1fa9-4a81-8015-a7fac922d1c3"}, { new Terminator(DelimiterType.LeftParenthesis), "78cca9ee-10ea-4165-bed3-45ccebd8753f"}, { Terminator.IdentifierTerminator, "31a64221-d8c9-4a33-936b-76f0337941b9"}, { new Terminator(KeywordType.Not), "c0b190f8-cfb2-426c-8a63-16f3a632b49b"}, { new Terminator(OperatorType.Minus), "73325f12-9d72-4578-9dc9-489597376504"},}, new Dictionary<Terminator, ReduceInformation>{ }, "73325f12-9d72-4578-9dc9-489597376504") },
		{ "66aef84a-c4df-4151-b26c-6cab28af96c1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "ef7c0061-08cc-4d80-8ee6-133cae45c81d"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "66aef84a-c4df-4151-b26c-6cab28af96c1") },
		{ "652f8b39-10a5-49b4-8ced-2889862568df", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "652f8b39-10a5-49b4-8ced-2889862568df") },
		{ "bc6b7a63-88f4-4eeb-94db-f3677b3aa77b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "bc6b7a63-88f4-4eeb-94db-f3677b3aa77b") },
		{ "63820e3b-5e68-4e48-97db-b7b82f09ce2f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "c327dd11-fc13-4b2b-bd48-79bf31b92338"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "63820e3b-5e68-4e48-97db-b7b82f09ce2f") },
		{ "af567331-93f4-4450-9f7d-3b236bebd07a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "1e484a48-4532-44bb-acb1-65c4e82abeec"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "af567331-93f4-4450-9f7d-3b236bebd07a") },
		{ "07d9d974-ab84-4710-81d3-7f20c94c4017", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "07457ebc-9712-453b-8bb6-784d3af2ddeb"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "07d9d974-ab84-4710-81d3-7f20c94c4017") },
		{ "4dd0d283-371b-484a-8255-b8b94961d7b2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "4dd0d283-371b-484a-8255-b8b94961d7b2") },
		{ "881259a9-2d36-4f8f-a614-631d9df084d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "881259a9-2d36-4f8f-a614-631d9df084d1") },
		{ "641454df-ca11-46e6-92d5-b7172abbb85e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "822113d7-f28c-4602-bb21-2ee502fd8870"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "641454df-ca11-46e6-92d5-b7172abbb85e") },
		{ "011c3396-81ce-4fe3-9856-84b69764a78f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "d793b6e5-646a-4b39-af59-c57fa391b816"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "011c3396-81ce-4fe3-9856-84b69764a78f") },
		{ "fee56828-0e35-4559-841b-738ee6f970fd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "81454df6-b210-495f-a1fd-fafa24f3a6c3"}, { new NonTerminator(NonTerminatorType.Factor), "84bcb458-c266-4cd2-9243-3e037e493e90"}, { Terminator.NumberTerminator, "51e290b6-37e0-4cf3-b311-247de1a5e819"}, { new NonTerminator(NonTerminatorType.Variable), "7962cf3c-2542-413f-b317-280262bc110e"}, { new Terminator(DelimiterType.LeftParenthesis), "d762ead4-77ea-4d13-83ce-bd2ef66c871e"}, { Terminator.IdentifierTerminator, "360d64a9-cbd4-47f4-ae8e-c581c007d4e6"}, { new Terminator(KeywordType.Not), "927a5bc5-bef9-416f-ab4f-ca5c55787148"}, { new Terminator(OperatorType.Minus), "be3688dc-6d78-4b4a-ab01-cde694894c1c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fee56828-0e35-4559-841b-738ee6f970fd") },
		{ "a8c4264f-1575-4ac5-b12e-44888e8b3877", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "71feeff6-545d-4d16-afe5-23d878fad9ae"}, { Terminator.NumberTerminator, "51e290b6-37e0-4cf3-b311-247de1a5e819"}, { new NonTerminator(NonTerminatorType.Variable), "7962cf3c-2542-413f-b317-280262bc110e"}, { new Terminator(DelimiterType.LeftParenthesis), "d762ead4-77ea-4d13-83ce-bd2ef66c871e"}, { Terminator.IdentifierTerminator, "360d64a9-cbd4-47f4-ae8e-c581c007d4e6"}, { new Terminator(KeywordType.Not), "927a5bc5-bef9-416f-ab4f-ca5c55787148"}, { new Terminator(OperatorType.Minus), "be3688dc-6d78-4b4a-ab01-cde694894c1c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a8c4264f-1575-4ac5-b12e-44888e8b3877") },
		{ "d6aaf87c-cd5e-4598-8733-261c6eb02766", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "05bf5a49-5a8b-49f6-ae30-8ea2129606bf"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d6aaf87c-cd5e-4598-8733-261c6eb02766") },
		{ "a161984a-5a7a-4db6-8523-9e94528f7847", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "37ebe9ba-38b6-4549-85e8-5de989586cd2"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a161984a-5a7a-4db6-8523-9e94528f7847") },
		{ "686a1337-616c-483c-ae57-da9aa186a476", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "686a1337-616c-483c-ae57-da9aa186a476") },
		{ "605b0134-7c11-4d34-bb23-3ad2b64e7a3f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "31efb023-5260-4c4a-b08f-73cecae05d35"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "605b0134-7c11-4d34-bb23-3ad2b64e7a3f") },
		{ "17d6b0c9-9d43-4805-9502-9b66d4ab4826", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "17d6b0c9-9d43-4805-9502-9b66d4ab4826") },
		{ "e159a84d-b36c-46a7-ba1d-58495ceb09cb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "e159a84d-b36c-46a7-ba1d-58495ceb09cb") },
		{ "f489c0fc-d63f-4a65-8045-bd4a8882bac4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "f489c0fc-d63f-4a65-8045-bd4a8882bac4") },
		{ "37ed8009-1a61-4dce-a2ec-2fecd6db8dd5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "37ed8009-1a61-4dce-a2ec-2fecd6db8dd5") },
		{ "67d065f5-7da8-4743-8ae1-7a4e6c033176", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, }, "67d065f5-7da8-4743-8ae1-7a4e6c033176") },
		{ "1be0aafd-43a2-4ee9-be4f-7969000cce98", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Do), "d2c9ac63-fe74-45bd-a718-ee8f08309a12"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1be0aafd-43a2-4ee9-be4f-7969000cce98") },
		{ "32d24d83-e9bb-4ca3-a2a7-4857f740029f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "94cea5a3-a84e-44d6-8d6d-5154e996d58a"}, { new NonTerminator(NonTerminatorType.Factor), "2011e414-cfed-4833-855a-e926e29005b1"}, { Terminator.NumberTerminator, "3dc4f03e-bcbe-4f0d-bbd5-9830a09661c4"}, { new NonTerminator(NonTerminatorType.Variable), "422611f6-1fa9-4a81-8015-a7fac922d1c3"}, { new Terminator(DelimiterType.LeftParenthesis), "78cca9ee-10ea-4165-bed3-45ccebd8753f"}, { Terminator.IdentifierTerminator, "31a64221-d8c9-4a33-936b-76f0337941b9"}, { new Terminator(KeywordType.Not), "c0b190f8-cfb2-426c-8a63-16f3a632b49b"}, { new Terminator(OperatorType.Minus), "73325f12-9d72-4578-9dc9-489597376504"},}, new Dictionary<Terminator, ReduceInformation>{ }, "32d24d83-e9bb-4ca3-a2a7-4857f740029f") },
		{ "dea17e32-ed88-42ee-95cd-fe2cb1d561d2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "6b76d388-b1d7-442a-ae25-9e3981b81097"}, { Terminator.NumberTerminator, "3dc4f03e-bcbe-4f0d-bbd5-9830a09661c4"}, { new NonTerminator(NonTerminatorType.Variable), "422611f6-1fa9-4a81-8015-a7fac922d1c3"}, { new Terminator(DelimiterType.LeftParenthesis), "78cca9ee-10ea-4165-bed3-45ccebd8753f"}, { Terminator.IdentifierTerminator, "31a64221-d8c9-4a33-936b-76f0337941b9"}, { new Terminator(KeywordType.Not), "c0b190f8-cfb2-426c-8a63-16f3a632b49b"}, { new Terminator(OperatorType.Minus), "73325f12-9d72-4578-9dc9-489597376504"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dea17e32-ed88-42ee-95cd-fe2cb1d561d2") },
		{ "04420f81-c239-4ead-af8f-706696a77692", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a93ffe25-b76f-4feb-ae4c-c2f8dcbf6557"},}, new Dictionary<Terminator, ReduceInformation>{ }, "04420f81-c239-4ead-af8f-706696a77692") },
		{ "8fee768d-6560-49a0-b12b-cd997fe28b91", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "9afd86ed-0e66-47b1-87e5-d5386239e0c9"}, { new NonTerminator(NonTerminatorType.Expression), "48274443-b7c1-435d-aaaa-8a09601273f9"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "86f8df3e-3b19-48fe-a2cd-34bc036a4d16"}, { new NonTerminator(NonTerminatorType.Term), "2db80379-6dfa-40eb-9c52-02ab09351164"}, { new NonTerminator(NonTerminatorType.Factor), "0f734f56-cf8a-4d37-bb2a-7be4cb4cda0d"}, { Terminator.NumberTerminator, "12f3cddc-f277-4425-9eca-38884494e86e"}, { new NonTerminator(NonTerminatorType.Variable), "87838683-e4f8-4027-88ee-75bc41d6c7d3"}, { new Terminator(DelimiterType.LeftParenthesis), "94925daf-54ea-4162-ae04-0fa6bb913c83"}, { Terminator.IdentifierTerminator, "7546d1eb-c40e-4e41-83e9-0ffc2b4f587f"}, { new Terminator(KeywordType.Not), "4f30dea8-6760-46df-809f-f6b6474b2c8b"}, { new Terminator(OperatorType.Minus), "5dceebf4-1f3b-4767-b816-cf24661377ff"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8fee768d-6560-49a0-b12b-cd997fe28b91") },
		{ "3bd432d4-d808-4461-b79e-be0928ede65f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "3bd432d4-d808-4461-b79e-be0928ede65f") },
		{ "145b205d-5cfa-41e8-8955-b37a0912bb14", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "dbcfeea3-e902-413c-8880-3e6ea7f5ee89"}, { new NonTerminator(NonTerminatorType.Expression), "09cac309-abed-414e-8474-6b60d13f6cfa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "bccb9e4b-0144-4242-9be0-44e084fa0288"}, { new NonTerminator(NonTerminatorType.Term), "71aebecb-07f7-4c81-835c-c9d30e8c591c"}, { new NonTerminator(NonTerminatorType.Factor), "c912911e-3115-461e-a0b0-8a928d65964f"}, { Terminator.NumberTerminator, "f73caf00-2936-4127-8f89-315d90db052b"}, { new NonTerminator(NonTerminatorType.Variable), "ba1ee670-0706-4663-b78a-af6dc5c23f48"}, { new Terminator(DelimiterType.LeftParenthesis), "2a561d9c-4157-4dc7-be4c-4d914f111ffe"}, { Terminator.IdentifierTerminator, "041f60de-3c2b-4aaf-8284-b02aa5db505f"}, { new Terminator(KeywordType.Not), "65c46b92-1ace-4c7e-95cd-3ded2b9a2b4c"}, { new Terminator(OperatorType.Minus), "7928c972-6f98-47d1-a422-bdd087c5c11e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "145b205d-5cfa-41e8-8955-b37a0912bb14") },
		{ "a25f790d-1583-4815-aa3e-5a8fc47b52f0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "a25f790d-1583-4815-aa3e-5a8fc47b52f0") },
		{ "03d7a6b0-0d6c-465a-a0df-06accd17df6c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "03d7a6b0-0d6c-465a-a0df-06accd17df6c") },
		{ "c327dd11-fc13-4b2b-bd48-79bf31b92338", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "c327dd11-fc13-4b2b-bd48-79bf31b92338") },
		{ "1e484a48-4532-44bb-acb1-65c4e82abeec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "1e484a48-4532-44bb-acb1-65c4e82abeec") },
		{ "822113d7-f28c-4602-bb21-2ee502fd8870", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "822113d7-f28c-4602-bb21-2ee502fd8870") },
		{ "d793b6e5-646a-4b39-af59-c57fa391b816", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "d793b6e5-646a-4b39-af59-c57fa391b816") },
		{ "81454df6-b210-495f-a1fd-fafa24f3a6c3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "a8c4264f-1575-4ac5-b12e-44888e8b3877"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "81454df6-b210-495f-a1fd-fafa24f3a6c3") },
		{ "71feeff6-545d-4d16-afe5-23d878fad9ae", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "71feeff6-545d-4d16-afe5-23d878fad9ae") },
		{ "05bf5a49-5a8b-49f6-ae30-8ea2129606bf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "05bf5a49-5a8b-49f6-ae30-8ea2129606bf") },
		{ "37ebe9ba-38b6-4549-85e8-5de989586cd2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "770dc00f-dfb3-480c-ac60-897d1c71ff94"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "37ebe9ba-38b6-4549-85e8-5de989586cd2") },
		{ "31efb023-5260-4c4a-b08f-73cecae05d35", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "4fad9a95-425d-4461-a901-756627174c1a"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "31efb023-5260-4c4a-b08f-73cecae05d35") },
		{ "d2c9ac63-fe74-45bd-a718-ee8f08309a12", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "569da068-692b-4a84-90a7-ba26a8c74a89"}, { new NonTerminator(NonTerminatorType.Variable), "05c3dea6-abe5-485c-8fa4-9e7a2af0498c"}, { Terminator.IdentifierTerminator, "bf56ce79-ff0a-4859-b78f-d27987ca5b26"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "36a10a85-e2d6-4119-9b5a-21b6d9fa8c7d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "b9faa148-d99c-4da2-90bd-dc5cc36c5687"}, { new Terminator(KeywordType.If), "cc979e47-296d-4fda-82eb-96b5a942102a"}, { new Terminator(KeywordType.For), "84cd7591-19e5-4b45-be6d-22625f85cf37"}, { new Terminator(KeywordType.Begin), "8d7a1805-2634-4dc3-95e4-15207f4d8e1f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "d2c9ac63-fe74-45bd-a718-ee8f08309a12") },
		{ "94cea5a3-a84e-44d6-8d6d-5154e996d58a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "dea17e32-ed88-42ee-95cd-fe2cb1d561d2"}, { new Terminator(OperatorType.Multiply), "468d595b-f6df-4fdb-bb63-a555c3440509"}, { new Terminator(OperatorType.Divide), "cf2994e3-ee9b-4ddb-baf5-e30dfa0be993"}, { new Terminator(KeywordType.Divide), "6058f285-f42b-4688-8991-89f53d3b025a"}, { new Terminator(KeywordType.Mod), "4b86a3b2-9a85-4208-be25-5fc3f6e8a868"}, { new Terminator(KeywordType.And), "3622ef10-e09f-47d6-a683-b9ae2016733c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "94cea5a3-a84e-44d6-8d6d-5154e996d58a") },
		{ "6b76d388-b1d7-442a-ae25-9e3981b81097", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "6b76d388-b1d7-442a-ae25-9e3981b81097") },
		{ "a93ffe25-b76f-4feb-ae4c-c2f8dcbf6557", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "a93ffe25-b76f-4feb-ae4c-c2f8dcbf6557") },
		{ "9afd86ed-0e66-47b1-87e5-d5386239e0c9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "17be6a0b-33f0-4c14-9431-cd7e3945c19b"}, { new Terminator(DelimiterType.Comma), "70ed92ac-d8fb-47e4-ae4f-463cd4d3a2a7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9afd86ed-0e66-47b1-87e5-d5386239e0c9") },
		{ "dbcfeea3-e902-413c-8880-3e6ea7f5ee89", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "3a4b8c24-4f5c-4326-998e-6bf4aab8642a"}, { new Terminator(DelimiterType.Comma), "a26b6e4c-56b3-4f5a-b969-ae4555e304a6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dbcfeea3-e902-413c-8880-3e6ea7f5ee89") },
		{ "770dc00f-dfb3-480c-ac60-897d1c71ff94", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "770dc00f-dfb3-480c-ac60-897d1c71ff94") },
		{ "4fad9a95-425d-4461-a901-756627174c1a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "4fad9a95-425d-4461-a901-756627174c1a") },
		{ "569da068-692b-4a84-90a7-ba26a8c74a89", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, }, "569da068-692b-4a84-90a7-ba26a8c74a89") },
		{ "17be6a0b-33f0-4c14-9431-cd7e3945c19b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "17be6a0b-33f0-4c14-9431-cd7e3945c19b") },
		{ "3a4b8c24-4f5c-4326-998e-6bf4aab8642a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "3a4b8c24-4f5c-4326-998e-6bf4aab8642a") },
	};

    private GeneratedGrammarParser()
    {
        foreach(GeneratedTransformer transformer in s_transformers.Values)
        {
            transformer.ConstructShiftTable(s_transformers);
        }
    }

    private static GeneratedGrammarParser s_instance = new GeneratedGrammarParser();

    public static GeneratedGrammarParser Instance => s_instance;
    
	public override ITransformer BeginTransformer => s_transformers["f73d22cc-ac40-46ec-8150-8772c03417b9"];
	public override NonTerminator Begin => new NonTerminator(NonTerminatorType.StartNonTerminator);
}
